package open_telemetryv3
import "github.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/open_telemetry/v3"
Index ¶
- Variables
- type OpenTelemetryAccessLogConfig
- func (*OpenTelemetryAccessLogConfig) Descriptor() ([]byte, []int)
- func (x *OpenTelemetryAccessLogConfig) GetAttributes() *v1.KeyValueList
- func (x *OpenTelemetryAccessLogConfig) GetBody() *v1.AnyValue
- func (x *OpenTelemetryAccessLogConfig) GetBufferFlushInterval() *durationpb.Duration
- func (x *OpenTelemetryAccessLogConfig) GetBufferSizeBytes() *wrapperspb.UInt32Value
- func (x *OpenTelemetryAccessLogConfig) GetCommonConfig() *v3.CommonGrpcAccessLogConfig
- func (x *OpenTelemetryAccessLogConfig) GetCustomTags() []*v32.CustomTag
- func (x *OpenTelemetryAccessLogConfig) GetDisableBuiltinLabels() bool
- func (x *OpenTelemetryAccessLogConfig) GetFilterStateObjectsToLog() []string
- func (x *OpenTelemetryAccessLogConfig) GetFormatters() []*v31.TypedExtensionConfig
- func (x *OpenTelemetryAccessLogConfig) GetGrpcService() *v31.GrpcService
- func (x *OpenTelemetryAccessLogConfig) GetHttpService() *v31.HttpService
- func (x *OpenTelemetryAccessLogConfig) GetLogName() string
- func (x *OpenTelemetryAccessLogConfig) GetResourceAttributes() *v1.KeyValueList
- func (x *OpenTelemetryAccessLogConfig) GetStatPrefix() string
- func (*OpenTelemetryAccessLogConfig) ProtoMessage()
- func (x *OpenTelemetryAccessLogConfig) ProtoReflect() protoreflect.Message
- func (x *OpenTelemetryAccessLogConfig) Reset()
- func (x *OpenTelemetryAccessLogConfig) String() string
- func (m *OpenTelemetryAccessLogConfig) Validate() error
- func (m *OpenTelemetryAccessLogConfig) ValidateAll() error
- type OpenTelemetryAccessLogConfigMultiError
- func (m OpenTelemetryAccessLogConfigMultiError) AllErrors() []error
- func (m OpenTelemetryAccessLogConfigMultiError) Error() string
- type OpenTelemetryAccessLogConfigValidationError
- func (e OpenTelemetryAccessLogConfigValidationError) Cause() error
- func (e OpenTelemetryAccessLogConfigValidationError) Error() string
- func (e OpenTelemetryAccessLogConfigValidationError) ErrorName() string
- func (e OpenTelemetryAccessLogConfigValidationError) Field() string
- func (e OpenTelemetryAccessLogConfigValidationError) Key() bool
- func (e OpenTelemetryAccessLogConfigValidationError) Reason() string
Variables ¶
var File_envoy_extensions_access_loggers_open_telemetry_v3_logs_service_proto protoreflect.FileDescriptor
Types ¶
type OpenTelemetryAccessLogConfig ¶
type OpenTelemetryAccessLogConfig struct {
// [#comment:TODO(itamarkam): add 'filter_state_objects_to_log' to logs.]
// Deprecated. Use “grpc_service“ or “http_service“ instead.
//
// Deprecated: Marked as deprecated in envoy/extensions/access_loggers/open_telemetry/v3/logs_service.proto.
CommonConfig *v3.CommonGrpcAccessLogConfig `protobuf:"bytes,1,opt,name=common_config,json=commonConfig,proto3" json:"common_config,omitempty"`
// The upstream HTTP cluster that will receive OTLP logs via
// `OTLP/HTTP <https://opentelemetry.io/docs/specs/otlp/#otlphttp>`_.
// Note: Only one of “common_config“, “grpc_service“, or “http_service“ may be used.
//
// .. note::
//
// The ``request_headers_to_add`` property in the OTLP HTTP exporter service
// does not support the :ref:`format specifier <config_access_log_format>` as used for
// :ref:`HTTP access logging <config_access_log>`.
// The values configured are added as HTTP headers on the OTLP export request
// without any formatting applied.
HttpService *v31.HttpService `protobuf:"bytes,8,opt,name=http_service,json=httpService,proto3" json:"http_service,omitempty"`
// The upstream gRPC cluster that will receive OTLP logs.
// Note: Only one of “common_config“, “grpc_service“, or “http_service“ may be used.
// This field is preferred over “common_config.grpc_service“.
GrpcService *v31.GrpcService `protobuf:"bytes,9,opt,name=grpc_service,json=grpcService,proto3" json:"grpc_service,omitempty"`
// If specified, Envoy will not generate built-in resource labels
// like “log_name“, “zone_name“, “cluster_name“, “node_name“.
DisableBuiltinLabels bool `protobuf:"varint,5,opt,name=disable_builtin_labels,json=disableBuiltinLabels,proto3" json:"disable_builtin_labels,omitempty"`
// OpenTelemetry `Resource <https://github.com/open-telemetry/opentelemetry-proto/blob/main/opentelemetry/proto/logs/v1/logs.proto#L51>`_
// attributes are filled with Envoy node info.
// Example: “resource_attributes { values { key: "region" value { string_value: "cn-north-7" } } }“.
ResourceAttributes *v1.KeyValueList `protobuf:"bytes,4,opt,name=resource_attributes,json=resourceAttributes,proto3" json:"resource_attributes,omitempty"`
// OpenTelemetry `LogResource <https://github.com/open-telemetry/opentelemetry-proto/blob/main/opentelemetry/proto/logs/v1/logs.proto>`_
// fields, following `Envoy access logging formatting <https://www.envoyproxy.io/docs/envoy/latest/configuration/observability/access_log/usage>`_.
//
// See 'body' in the LogResource proto for more details.
// Example: “body { string_value: "%PROTOCOL%" }“.
Body *v1.AnyValue `protobuf:"bytes,2,opt,name=body,proto3" json:"body,omitempty"`
// See 'attributes' in the LogResource proto for more details.
// Example: “attributes { values { key: "user_agent" value { string_value: "%REQ(USER-AGENT)%" } } }“.
Attributes *v1.KeyValueList `protobuf:"bytes,3,opt,name=attributes,proto3" json:"attributes,omitempty"`
// Optional. Additional prefix to use on OpenTelemetry access logger stats. If empty, the stats will be rooted at
// “access_logs.open_telemetry_access_log.“. If non-empty, stats will be rooted at
// “access_logs.open_telemetry_access_log.<stat_prefix>.“.
StatPrefix string `protobuf:"bytes,6,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
// Specifies a collection of Formatter plugins that can be called from the access log configuration.
// See the formatters extensions documentation for details.
// [#extension-category: envoy.formatter]
Formatters []*v31.TypedExtensionConfig `protobuf:"bytes,7,rep,name=formatters,proto3" json:"formatters,omitempty"`
LogName string `protobuf:"bytes,10,opt,name=log_name,json=logName,proto3" json:"log_name,omitempty"`
// The interval for flushing access logs to the transport. Default: 1 second.
BufferFlushInterval *durationpb.Duration `protobuf:"bytes,11,opt,name=buffer_flush_interval,json=bufferFlushInterval,proto3" json:"buffer_flush_interval,omitempty"`
// Soft size limit in bytes for the access log buffer. When the buffer exceeds
// this limit, logs will be flushed. Default: 16KB.
BufferSizeBytes *wrapperspb.UInt32Value `protobuf:"bytes,12,opt,name=buffer_size_bytes,json=bufferSizeBytes,proto3" json:"buffer_size_bytes,omitempty"`
// Additional filter state objects to log as attributes.
FilterStateObjectsToLog []string `protobuf:"bytes,13,rep,name=filter_state_objects_to_log,json=filterStateObjectsToLog,proto3" json:"filter_state_objects_to_log,omitempty"`
// Custom tags to include as log attributes.
CustomTags []*v32.CustomTag `protobuf:"bytes,14,rep,name=custom_tags,json=customTags,proto3" json:"custom_tags,omitempty"`
// contains filtered or unexported fields
}
Configuration for the built-in “envoy.access_loggers.open_telemetry“ :ref:`AccessLog <envoy_v3_api_msg_config.accesslog.v3.AccessLog>`. This configuration will populate `opentelemetry.proto.collector.v1.logs.ExportLogsServiceRequest.resource_logs <https://github.com/open-telemetry/opentelemetry-proto/blob/main/opentelemetry/proto/collector/logs/v1/logs_service.proto>`_. In addition, the request start time is set in the dedicated field. [#extension: envoy.access_loggers.open_telemetry] [#next-free-field: 15]
func (*OpenTelemetryAccessLogConfig) Descriptor ¶
func (*OpenTelemetryAccessLogConfig) Descriptor() ([]byte, []int)
Deprecated: Use OpenTelemetryAccessLogConfig.ProtoReflect.Descriptor instead.
func (*OpenTelemetryAccessLogConfig) GetAttributes ¶
func (x *OpenTelemetryAccessLogConfig) GetAttributes() *v1.KeyValueList
func (*OpenTelemetryAccessLogConfig) GetBody ¶
func (x *OpenTelemetryAccessLogConfig) GetBody() *v1.AnyValue
func (*OpenTelemetryAccessLogConfig) GetBufferFlushInterval ¶
func (x *OpenTelemetryAccessLogConfig) GetBufferFlushInterval() *durationpb.Duration
func (*OpenTelemetryAccessLogConfig) GetBufferSizeBytes ¶
func (x *OpenTelemetryAccessLogConfig) GetBufferSizeBytes() *wrapperspb.UInt32Value
func (*OpenTelemetryAccessLogConfig) GetCommonConfig ¶
func (x *OpenTelemetryAccessLogConfig) GetCommonConfig() *v3.CommonGrpcAccessLogConfig
Deprecated: Marked as deprecated in envoy/extensions/access_loggers/open_telemetry/v3/logs_service.proto.
func (*OpenTelemetryAccessLogConfig) GetCustomTags ¶
func (x *OpenTelemetryAccessLogConfig) GetCustomTags() []*v32.CustomTag
func (*OpenTelemetryAccessLogConfig) GetDisableBuiltinLabels ¶
func (x *OpenTelemetryAccessLogConfig) GetDisableBuiltinLabels() bool
func (*OpenTelemetryAccessLogConfig) GetFilterStateObjectsToLog ¶
func (x *OpenTelemetryAccessLogConfig) GetFilterStateObjectsToLog() []string
func (*OpenTelemetryAccessLogConfig) GetFormatters ¶
func (x *OpenTelemetryAccessLogConfig) GetFormatters() []*v31.TypedExtensionConfig
func (*OpenTelemetryAccessLogConfig) GetGrpcService ¶
func (x *OpenTelemetryAccessLogConfig) GetGrpcService() *v31.GrpcService
func (*OpenTelemetryAccessLogConfig) GetHttpService ¶
func (x *OpenTelemetryAccessLogConfig) GetHttpService() *v31.HttpService
func (*OpenTelemetryAccessLogConfig) GetLogName ¶
func (x *OpenTelemetryAccessLogConfig) GetLogName() string
func (*OpenTelemetryAccessLogConfig) GetResourceAttributes ¶
func (x *OpenTelemetryAccessLogConfig) GetResourceAttributes() *v1.KeyValueList
func (*OpenTelemetryAccessLogConfig) GetStatPrefix ¶
func (x *OpenTelemetryAccessLogConfig) GetStatPrefix() string
func (*OpenTelemetryAccessLogConfig) ProtoMessage ¶
func (*OpenTelemetryAccessLogConfig) ProtoMessage()
func (*OpenTelemetryAccessLogConfig) ProtoReflect ¶
func (x *OpenTelemetryAccessLogConfig) ProtoReflect() protoreflect.Message
func (*OpenTelemetryAccessLogConfig) Reset ¶
func (x *OpenTelemetryAccessLogConfig) Reset()
func (*OpenTelemetryAccessLogConfig) String ¶
func (x *OpenTelemetryAccessLogConfig) String() string
func (*OpenTelemetryAccessLogConfig) Validate ¶
func (m *OpenTelemetryAccessLogConfig) Validate() error
Validate checks the field values on OpenTelemetryAccessLogConfig with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*OpenTelemetryAccessLogConfig) ValidateAll ¶
func (m *OpenTelemetryAccessLogConfig) ValidateAll() error
ValidateAll checks the field values on OpenTelemetryAccessLogConfig with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in OpenTelemetryAccessLogConfigMultiError, or nil if none found.
type OpenTelemetryAccessLogConfigMultiError ¶
type OpenTelemetryAccessLogConfigMultiError []error
OpenTelemetryAccessLogConfigMultiError is an error wrapping multiple validation errors returned by OpenTelemetryAccessLogConfig.ValidateAll() if the designated constraints aren't met.
func (OpenTelemetryAccessLogConfigMultiError) AllErrors ¶
func (m OpenTelemetryAccessLogConfigMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (OpenTelemetryAccessLogConfigMultiError) Error ¶
func (m OpenTelemetryAccessLogConfigMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type OpenTelemetryAccessLogConfigValidationError ¶
type OpenTelemetryAccessLogConfigValidationError struct {
// contains filtered or unexported fields
}
OpenTelemetryAccessLogConfigValidationError is the validation error returned by OpenTelemetryAccessLogConfig.Validate if the designated constraints aren't met.
func (OpenTelemetryAccessLogConfigValidationError) Cause ¶
func (e OpenTelemetryAccessLogConfigValidationError) Cause() error
Cause function returns cause value.
func (OpenTelemetryAccessLogConfigValidationError) Error ¶
func (e OpenTelemetryAccessLogConfigValidationError) Error() string
Error satisfies the builtin error interface
func (OpenTelemetryAccessLogConfigValidationError) ErrorName ¶
func (e OpenTelemetryAccessLogConfigValidationError) ErrorName() string
ErrorName returns error name.
func (OpenTelemetryAccessLogConfigValidationError) Field ¶
func (e OpenTelemetryAccessLogConfigValidationError) Field() string
Field function returns field value.
func (OpenTelemetryAccessLogConfigValidationError) Key ¶
func (e OpenTelemetryAccessLogConfigValidationError) Key() bool
Key function returns key value.
func (OpenTelemetryAccessLogConfigValidationError) Reason ¶
func (e OpenTelemetryAccessLogConfigValidationError) Reason() string
Reason function returns reason value.
Source Files ¶
logs_service.pb.go logs_service.pb.validate.go
- Version
- v1.37.0 (latest)
- Published
- Jan 13, 2026
- Platform
- linux/amd64
- Imports
- 25 packages
- Last checked
- 1 hour ago –
Tools for package owners.