package awsv3

import "github.com/envoyproxy/go-control-plane/envoy/extensions/common/aws/v3"

Index

Variables

var File_envoy_extensions_common_aws_v3_credential_provider_proto protoreflect.FileDescriptor

Types

type AssumeRoleCredentialProvider

type AssumeRoleCredentialProvider struct {

	// The ARN of the role to assume.
	RoleArn string `protobuf:"bytes,1,opt,name=role_arn,json=roleArn,proto3" json:"role_arn,omitempty"`
	// An optional role session name, used when identifying the role in subsequent AWS API calls. If not provided, the role session name will default
	// to the current timestamp.
	RoleSessionName string `protobuf:"bytes,2,opt,name=role_session_name,json=roleSessionName,proto3" json:"role_session_name,omitempty"`
	// Optional string value to use as the externalId
	ExternalId string `protobuf:"bytes,3,opt,name=external_id,json=externalId,proto3" json:"external_id,omitempty"`
	// An optional duration, in seconds, of the role session. Minimum role duration is 900s (5 minutes) and maximum is 43200s (12 hours).
	// If the session duration is not provided, the default will be determined using the `table described here <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_manage-assume.html>`_.
	SessionDuration *durationpb.Duration `protobuf:"bytes,4,opt,name=session_duration,json=sessionDuration,proto3" json:"session_duration,omitempty"`
	// The credential provider for signing the AssumeRole request. This is optional and if not set,
	// it will be retrieved from the procedure described in :ref:`config_http_filters_aws_request_signing`.
	// This list of credential providers cannot include an AssumeRole credential provider and if one is provided
	// it will be ignored.
	CredentialProvider *AwsCredentialProvider `protobuf:"bytes,5,opt,name=credential_provider,json=credentialProvider,proto3" json:"credential_provider,omitempty"`
	// contains filtered or unexported fields
}

Configuration to use `AssumeRole <https://docs.aws.amazon.com/STS/latest/APIReference/API_AssumeRole.html>`_ for retrieving new credentials, via role chaining. [#next-free-field: 6]

func (*AssumeRoleCredentialProvider) Descriptor

func (*AssumeRoleCredentialProvider) Descriptor() ([]byte, []int)

Deprecated: Use AssumeRoleCredentialProvider.ProtoReflect.Descriptor instead.

func (*AssumeRoleCredentialProvider) GetCredentialProvider

func (x *AssumeRoleCredentialProvider) GetCredentialProvider() *AwsCredentialProvider

func (*AssumeRoleCredentialProvider) GetExternalId

func (x *AssumeRoleCredentialProvider) GetExternalId() string

func (*AssumeRoleCredentialProvider) GetRoleArn

func (x *AssumeRoleCredentialProvider) GetRoleArn() string

func (*AssumeRoleCredentialProvider) GetRoleSessionName

func (x *AssumeRoleCredentialProvider) GetRoleSessionName() string

func (*AssumeRoleCredentialProvider) GetSessionDuration

func (x *AssumeRoleCredentialProvider) GetSessionDuration() *durationpb.Duration

func (*AssumeRoleCredentialProvider) ProtoMessage

func (*AssumeRoleCredentialProvider) ProtoMessage()

func (*AssumeRoleCredentialProvider) ProtoReflect

func (*AssumeRoleCredentialProvider) Reset

func (x *AssumeRoleCredentialProvider) Reset()

func (*AssumeRoleCredentialProvider) String

func (*AssumeRoleCredentialProvider) Validate

func (m *AssumeRoleCredentialProvider) Validate() error

Validate checks the field values on AssumeRoleCredentialProvider with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*AssumeRoleCredentialProvider) ValidateAll

func (m *AssumeRoleCredentialProvider) ValidateAll() error

ValidateAll checks the field values on AssumeRoleCredentialProvider with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in AssumeRoleCredentialProviderMultiError, or nil if none found.

type AssumeRoleCredentialProviderMultiError

type AssumeRoleCredentialProviderMultiError []error

AssumeRoleCredentialProviderMultiError is an error wrapping multiple validation errors returned by AssumeRoleCredentialProvider.ValidateAll() if the designated constraints aren't met.

func (AssumeRoleCredentialProviderMultiError) AllErrors

AllErrors returns a list of validation violation errors.

func (AssumeRoleCredentialProviderMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type AssumeRoleCredentialProviderValidationError

type AssumeRoleCredentialProviderValidationError struct {
	// contains filtered or unexported fields
}

AssumeRoleCredentialProviderValidationError is the validation error returned by AssumeRoleCredentialProvider.Validate if the designated constraints aren't met.

func (AssumeRoleCredentialProviderValidationError) Cause

Cause function returns cause value.

func (AssumeRoleCredentialProviderValidationError) Error

Error satisfies the builtin error interface

func (AssumeRoleCredentialProviderValidationError) ErrorName

ErrorName returns error name.

func (AssumeRoleCredentialProviderValidationError) Field

Field function returns field value.

func (AssumeRoleCredentialProviderValidationError) Key

Key function returns key value.

func (AssumeRoleCredentialProviderValidationError) Reason

Reason function returns reason value.

type AssumeRoleWithWebIdentityCredentialProvider

type AssumeRoleWithWebIdentityCredentialProvider struct {

	// Data source for a web identity token that is provided by the identity provider to assume the role.
	// If a “watched_directory“ is not provided, one will be automatically inferred from the directory of the token file. This is to ensure
	// that if the token file is rotated, the new token will be picked up. This behaviour differs from the standard envoy data source behavior, which does not
	// automatically watch the directory of a file data source.
	// Even when file rotation occurs, current credentials will continue to be used until they expire, at which point new credentials will be retrieved using the new token.
	WebIdentityTokenDataSource *v3.DataSource `protobuf:"bytes,1,opt,name=web_identity_token_data_source,json=webIdentityTokenDataSource,proto3" json:"web_identity_token_data_source,omitempty"`
	// The ARN of the role to assume.
	RoleArn string `protobuf:"bytes,2,opt,name=role_arn,json=roleArn,proto3" json:"role_arn,omitempty"`
	// Optional role session name to use in AssumeRoleWithWebIdentity API call.
	RoleSessionName string `protobuf:"bytes,3,opt,name=role_session_name,json=roleSessionName,proto3" json:"role_session_name,omitempty"`
	// contains filtered or unexported fields
}

Configuration to use `AssumeRoleWithWebIdentity <https://docs.aws.amazon.com/STS/latest/APIReference/API_AssumeRoleWithWebIdentity.html>`_ to retrieve AWS credentials.

func (*AssumeRoleWithWebIdentityCredentialProvider) Descriptor

Deprecated: Use AssumeRoleWithWebIdentityCredentialProvider.ProtoReflect.Descriptor instead.

func (*AssumeRoleWithWebIdentityCredentialProvider) GetRoleArn

func (*AssumeRoleWithWebIdentityCredentialProvider) GetRoleSessionName

func (x *AssumeRoleWithWebIdentityCredentialProvider) GetRoleSessionName() string

func (*AssumeRoleWithWebIdentityCredentialProvider) GetWebIdentityTokenDataSource

func (x *AssumeRoleWithWebIdentityCredentialProvider) GetWebIdentityTokenDataSource() *v3.DataSource

func (*AssumeRoleWithWebIdentityCredentialProvider) ProtoMessage

func (*AssumeRoleWithWebIdentityCredentialProvider) ProtoReflect

func (*AssumeRoleWithWebIdentityCredentialProvider) Reset

func (*AssumeRoleWithWebIdentityCredentialProvider) String

func (*AssumeRoleWithWebIdentityCredentialProvider) Validate

Validate checks the field values on AssumeRoleWithWebIdentityCredentialProvider with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*AssumeRoleWithWebIdentityCredentialProvider) ValidateAll

ValidateAll checks the field values on AssumeRoleWithWebIdentityCredentialProvider with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in AssumeRoleWithWebIdentityCredentialProviderMultiError, or nil if none found.

type AssumeRoleWithWebIdentityCredentialProviderMultiError

type AssumeRoleWithWebIdentityCredentialProviderMultiError []error

AssumeRoleWithWebIdentityCredentialProviderMultiError is an error wrapping multiple validation errors returned by AssumeRoleWithWebIdentityCredentialProvider.ValidateAll() if the designated constraints aren't met.

func (AssumeRoleWithWebIdentityCredentialProviderMultiError) AllErrors

AllErrors returns a list of validation violation errors.

func (AssumeRoleWithWebIdentityCredentialProviderMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type AssumeRoleWithWebIdentityCredentialProviderValidationError

type AssumeRoleWithWebIdentityCredentialProviderValidationError struct {
	// contains filtered or unexported fields
}

AssumeRoleWithWebIdentityCredentialProviderValidationError is the validation error returned by AssumeRoleWithWebIdentityCredentialProvider.Validate if the designated constraints aren't met.

func (AssumeRoleWithWebIdentityCredentialProviderValidationError) Cause

Cause function returns cause value.

func (AssumeRoleWithWebIdentityCredentialProviderValidationError) Error

Error satisfies the builtin error interface

func (AssumeRoleWithWebIdentityCredentialProviderValidationError) ErrorName

ErrorName returns error name.

func (AssumeRoleWithWebIdentityCredentialProviderValidationError) Field

Field function returns field value.

func (AssumeRoleWithWebIdentityCredentialProviderValidationError) Key

Key function returns key value.

func (AssumeRoleWithWebIdentityCredentialProviderValidationError) Reason

Reason function returns reason value.

type AwsCredentialProvider

type AwsCredentialProvider struct {

	// The option to use `AssumeRoleWithWebIdentity <https://docs.aws.amazon.com/STS/latest/APIReference/API_AssumeRoleWithWebIdentity.html>`_.
	AssumeRoleWithWebIdentityProvider *AssumeRoleWithWebIdentityCredentialProvider `protobuf:"bytes,1,opt,name=assume_role_with_web_identity_provider,json=assumeRoleWithWebIdentityProvider,proto3" json:"assume_role_with_web_identity_provider,omitempty"`
	// The option to use an inline credential. If inline credential is provided, no chain will be created and only the inline credential will be used.
	InlineCredential *InlineCredentialProvider `protobuf:"bytes,2,opt,name=inline_credential,json=inlineCredential,proto3" json:"inline_credential,omitempty"`
	// The option to specify parameters for credential retrieval from an envoy data source, such as a file in AWS credential format.
	CredentialsFileProvider *CredentialsFileCredentialProvider `protobuf:"bytes,3,opt,name=credentials_file_provider,json=credentialsFileProvider,proto3" json:"credentials_file_provider,omitempty"`
	// Create a custom credential provider chain instead of the default credential provider chain.
	// If set to TRUE, the credential provider chain that is created contains only those set in this credential provider message.
	// If set to FALSE, the settings provided here will act as modifiers to the default credential provider chain.
	// Defaults to FALSE.
	//
	// This has no effect if inline_credential is provided.
	CustomCredentialProviderChain bool `protobuf:"varint,4,opt,name=custom_credential_provider_chain,json=customCredentialProviderChain,proto3" json:"custom_credential_provider_chain,omitempty"`
	// The option to use `IAM Roles Anywhere <https://docs.aws.amazon.com/rolesanywhere/latest/userguide/introduction.html>`_.
	IamRolesAnywhereCredentialProvider *IAMRolesAnywhereCredentialProvider `protobuf:"bytes,5,opt,name=iam_roles_anywhere_credential_provider,json=iamRolesAnywhereCredentialProvider,proto3" json:"iam_roles_anywhere_credential_provider,omitempty"`
	// The option to use credentials sourced from standard `AWS configuration files <https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-files.html>`_.
	ConfigCredentialProvider *ConfigCredentialProvider `protobuf:"bytes,6,opt,name=config_credential_provider,json=configCredentialProvider,proto3" json:"config_credential_provider,omitempty"`
	// The option to use credentials sourced from `container environment variables <https://docs.aws.amazon.com/sdkref/latest/guide/feature-container-credentials.html>`_.
	ContainerCredentialProvider *ContainerCredentialProvider `protobuf:"bytes,7,opt,name=container_credential_provider,json=containerCredentialProvider,proto3" json:"container_credential_provider,omitempty"`
	// The option to use credentials sourced from `environment variables <https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-envvars.html>`_.
	EnvironmentCredentialProvider *EnvironmentCredentialProvider `protobuf:"bytes,8,opt,name=environment_credential_provider,json=environmentCredentialProvider,proto3" json:"environment_credential_provider,omitempty"`
	// The option to use credentials sourced from an EC2 `Instance Profile <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-roles-for-amazon-ec2.html>`_.
	InstanceProfileCredentialProvider *InstanceProfileCredentialProvider `protobuf:"bytes,9,opt,name=instance_profile_credential_provider,json=instanceProfileCredentialProvider,proto3" json:"instance_profile_credential_provider,omitempty"`
	// The option to use `STS:AssumeRole aka Role Chaining <https://docs.aws.amazon.com/STS/latest/APIReference/API_AssumeRole.html>`_.
	AssumeRoleCredentialProvider *AssumeRoleCredentialProvider `protobuf:"bytes,10,opt,name=assume_role_credential_provider,json=assumeRoleCredentialProvider,proto3" json:"assume_role_credential_provider,omitempty"`
	// contains filtered or unexported fields
}

Configuration for AWS credential provider. This is optional and the credentials are normally retrieved from the environment or AWS configuration files by following the default credential provider chain. However, this configuration can be used to override the default behavior. [#next-free-field: 11]

func (*AwsCredentialProvider) Descriptor

func (*AwsCredentialProvider) Descriptor() ([]byte, []int)

Deprecated: Use AwsCredentialProvider.ProtoReflect.Descriptor instead.

func (*AwsCredentialProvider) GetAssumeRoleCredentialProvider

func (x *AwsCredentialProvider) GetAssumeRoleCredentialProvider() *AssumeRoleCredentialProvider

func (*AwsCredentialProvider) GetAssumeRoleWithWebIdentityProvider

func (x *AwsCredentialProvider) GetAssumeRoleWithWebIdentityProvider() *AssumeRoleWithWebIdentityCredentialProvider

func (*AwsCredentialProvider) GetConfigCredentialProvider

func (x *AwsCredentialProvider) GetConfigCredentialProvider() *ConfigCredentialProvider

func (*AwsCredentialProvider) GetContainerCredentialProvider

func (x *AwsCredentialProvider) GetContainerCredentialProvider() *ContainerCredentialProvider

func (*AwsCredentialProvider) GetCredentialsFileProvider

func (x *AwsCredentialProvider) GetCredentialsFileProvider() *CredentialsFileCredentialProvider

func (*AwsCredentialProvider) GetCustomCredentialProviderChain

func (x *AwsCredentialProvider) GetCustomCredentialProviderChain() bool

func (*AwsCredentialProvider) GetEnvironmentCredentialProvider

func (x *AwsCredentialProvider) GetEnvironmentCredentialProvider() *EnvironmentCredentialProvider

func (*AwsCredentialProvider) GetIamRolesAnywhereCredentialProvider

func (x *AwsCredentialProvider) GetIamRolesAnywhereCredentialProvider() *IAMRolesAnywhereCredentialProvider

func (*AwsCredentialProvider) GetInlineCredential

func (x *AwsCredentialProvider) GetInlineCredential() *InlineCredentialProvider

func (*AwsCredentialProvider) GetInstanceProfileCredentialProvider

func (x *AwsCredentialProvider) GetInstanceProfileCredentialProvider() *InstanceProfileCredentialProvider

func (*AwsCredentialProvider) ProtoMessage

func (*AwsCredentialProvider) ProtoMessage()

func (*AwsCredentialProvider) ProtoReflect

func (x *AwsCredentialProvider) ProtoReflect() protoreflect.Message

func (*AwsCredentialProvider) Reset

func (x *AwsCredentialProvider) Reset()

func (*AwsCredentialProvider) String

func (x *AwsCredentialProvider) String() string

func (*AwsCredentialProvider) Validate

func (m *AwsCredentialProvider) Validate() error

Validate checks the field values on AwsCredentialProvider with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*AwsCredentialProvider) ValidateAll

func (m *AwsCredentialProvider) ValidateAll() error

ValidateAll checks the field values on AwsCredentialProvider with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in AwsCredentialProviderMultiError, or nil if none found.

type AwsCredentialProviderMultiError

type AwsCredentialProviderMultiError []error

AwsCredentialProviderMultiError is an error wrapping multiple validation errors returned by AwsCredentialProvider.ValidateAll() if the designated constraints aren't met.

func (AwsCredentialProviderMultiError) AllErrors

func (m AwsCredentialProviderMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (AwsCredentialProviderMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type AwsCredentialProviderValidationError

type AwsCredentialProviderValidationError struct {
	// contains filtered or unexported fields
}

AwsCredentialProviderValidationError is the validation error returned by AwsCredentialProvider.Validate if the designated constraints aren't met.

func (AwsCredentialProviderValidationError) Cause

Cause function returns cause value.

func (AwsCredentialProviderValidationError) Error

Error satisfies the builtin error interface

func (AwsCredentialProviderValidationError) ErrorName

ErrorName returns error name.

func (AwsCredentialProviderValidationError) Field

Field function returns field value.

func (AwsCredentialProviderValidationError) Key

Key function returns key value.

func (AwsCredentialProviderValidationError) Reason

Reason function returns reason value.

type ConfigCredentialProvider

type ConfigCredentialProvider struct {
	// contains filtered or unexported fields
}

The Config Credential Provider has no configurable parameters, but listing it in a custom credential provider chain will enable this credential provider.

func (*ConfigCredentialProvider) Descriptor

func (*ConfigCredentialProvider) Descriptor() ([]byte, []int)

Deprecated: Use ConfigCredentialProvider.ProtoReflect.Descriptor instead.

func (*ConfigCredentialProvider) ProtoMessage

func (*ConfigCredentialProvider) ProtoMessage()

func (*ConfigCredentialProvider) ProtoReflect

func (x *ConfigCredentialProvider) ProtoReflect() protoreflect.Message

func (*ConfigCredentialProvider) Reset

func (x *ConfigCredentialProvider) Reset()

func (*ConfigCredentialProvider) String

func (x *ConfigCredentialProvider) String() string

func (*ConfigCredentialProvider) Validate

func (m *ConfigCredentialProvider) Validate() error

Validate checks the field values on ConfigCredentialProvider with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*ConfigCredentialProvider) ValidateAll

func (m *ConfigCredentialProvider) ValidateAll() error

ValidateAll checks the field values on ConfigCredentialProvider with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in ConfigCredentialProviderMultiError, or nil if none found.

type ConfigCredentialProviderMultiError

type ConfigCredentialProviderMultiError []error

ConfigCredentialProviderMultiError is an error wrapping multiple validation errors returned by ConfigCredentialProvider.ValidateAll() if the designated constraints aren't met.

func (ConfigCredentialProviderMultiError) AllErrors

func (m ConfigCredentialProviderMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (ConfigCredentialProviderMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type ConfigCredentialProviderValidationError

type ConfigCredentialProviderValidationError struct {
	// contains filtered or unexported fields
}

ConfigCredentialProviderValidationError is the validation error returned by ConfigCredentialProvider.Validate if the designated constraints aren't met.

func (ConfigCredentialProviderValidationError) Cause

Cause function returns cause value.

func (ConfigCredentialProviderValidationError) Error

Error satisfies the builtin error interface

func (ConfigCredentialProviderValidationError) ErrorName

ErrorName returns error name.

func (ConfigCredentialProviderValidationError) Field

Field function returns field value.

func (ConfigCredentialProviderValidationError) Key

Key function returns key value.

func (ConfigCredentialProviderValidationError) Reason

Reason function returns reason value.

type ContainerCredentialProvider

type ContainerCredentialProvider struct {
	// contains filtered or unexported fields
}

The Container Credential Provider has no configurable parameters, but listing it in a custom credential provider chain will enable this credential provider.

func (*ContainerCredentialProvider) Descriptor

func (*ContainerCredentialProvider) Descriptor() ([]byte, []int)

Deprecated: Use ContainerCredentialProvider.ProtoReflect.Descriptor instead.

func (*ContainerCredentialProvider) ProtoMessage

func (*ContainerCredentialProvider) ProtoMessage()

func (*ContainerCredentialProvider) ProtoReflect

func (*ContainerCredentialProvider) Reset

func (x *ContainerCredentialProvider) Reset()

func (*ContainerCredentialProvider) String

func (x *ContainerCredentialProvider) String() string

func (*ContainerCredentialProvider) Validate

func (m *ContainerCredentialProvider) Validate() error

Validate checks the field values on ContainerCredentialProvider with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*ContainerCredentialProvider) ValidateAll

func (m *ContainerCredentialProvider) ValidateAll() error

ValidateAll checks the field values on ContainerCredentialProvider with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in ContainerCredentialProviderMultiError, or nil if none found.

type ContainerCredentialProviderMultiError

type ContainerCredentialProviderMultiError []error

ContainerCredentialProviderMultiError is an error wrapping multiple validation errors returned by ContainerCredentialProvider.ValidateAll() if the designated constraints aren't met.

func (ContainerCredentialProviderMultiError) AllErrors

AllErrors returns a list of validation violation errors.

func (ContainerCredentialProviderMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type ContainerCredentialProviderValidationError

type ContainerCredentialProviderValidationError struct {
	// contains filtered or unexported fields
}

ContainerCredentialProviderValidationError is the validation error returned by ContainerCredentialProvider.Validate if the designated constraints aren't met.

func (ContainerCredentialProviderValidationError) Cause

Cause function returns cause value.

func (ContainerCredentialProviderValidationError) Error

Error satisfies the builtin error interface

func (ContainerCredentialProviderValidationError) ErrorName

ErrorName returns error name.

func (ContainerCredentialProviderValidationError) Field

Field function returns field value.

func (ContainerCredentialProviderValidationError) Key

Key function returns key value.

func (ContainerCredentialProviderValidationError) Reason

Reason function returns reason value.

type CredentialsFileCredentialProvider

type CredentialsFileCredentialProvider struct {

	// Data source from which to retrieve AWS credentials
	// When using this data source, if a “watched_directory“ is provided, the credential file will be re-read when a file move is detected.
	// See :ref:`watched_directory <envoy_v3_api_msg_config.core.v3.DataSource>` for more information about the “watched_directory“ field.
	CredentialsDataSource *v3.DataSource `protobuf:"bytes,1,opt,name=credentials_data_source,json=credentialsDataSource,proto3" json:"credentials_data_source,omitempty"`
	// The profile within the credentials_file data source. If not provided, the default profile will be used.
	Profile string `protobuf:"bytes,2,opt,name=profile,proto3" json:"profile,omitempty"`
	// contains filtered or unexported fields
}

func (*CredentialsFileCredentialProvider) Descriptor

func (*CredentialsFileCredentialProvider) Descriptor() ([]byte, []int)

Deprecated: Use CredentialsFileCredentialProvider.ProtoReflect.Descriptor instead.

func (*CredentialsFileCredentialProvider) GetCredentialsDataSource

func (x *CredentialsFileCredentialProvider) GetCredentialsDataSource() *v3.DataSource

func (*CredentialsFileCredentialProvider) GetProfile

func (x *CredentialsFileCredentialProvider) GetProfile() string

func (*CredentialsFileCredentialProvider) ProtoMessage

func (*CredentialsFileCredentialProvider) ProtoMessage()

func (*CredentialsFileCredentialProvider) ProtoReflect

func (*CredentialsFileCredentialProvider) Reset

func (*CredentialsFileCredentialProvider) String

func (*CredentialsFileCredentialProvider) Validate

Validate checks the field values on CredentialsFileCredentialProvider with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*CredentialsFileCredentialProvider) ValidateAll

func (m *CredentialsFileCredentialProvider) ValidateAll() error

ValidateAll checks the field values on CredentialsFileCredentialProvider with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in CredentialsFileCredentialProviderMultiError, or nil if none found.

type CredentialsFileCredentialProviderMultiError

type CredentialsFileCredentialProviderMultiError []error

CredentialsFileCredentialProviderMultiError is an error wrapping multiple validation errors returned by CredentialsFileCredentialProvider.ValidateAll() if the designated constraints aren't met.

func (CredentialsFileCredentialProviderMultiError) AllErrors

AllErrors returns a list of validation violation errors.

func (CredentialsFileCredentialProviderMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type CredentialsFileCredentialProviderValidationError

type CredentialsFileCredentialProviderValidationError struct {
	// contains filtered or unexported fields
}

CredentialsFileCredentialProviderValidationError is the validation error returned by CredentialsFileCredentialProvider.Validate if the designated constraints aren't met.

func (CredentialsFileCredentialProviderValidationError) Cause

Cause function returns cause value.

func (CredentialsFileCredentialProviderValidationError) Error

Error satisfies the builtin error interface

func (CredentialsFileCredentialProviderValidationError) ErrorName

ErrorName returns error name.

func (CredentialsFileCredentialProviderValidationError) Field

Field function returns field value.

func (CredentialsFileCredentialProviderValidationError) Key

Key function returns key value.

func (CredentialsFileCredentialProviderValidationError) Reason

Reason function returns reason value.

type EnvironmentCredentialProvider

type EnvironmentCredentialProvider struct {
	// contains filtered or unexported fields
}

The Environment Credential Provider has no configurable parameters, but listing it in a custom credential provider chain will enable this credential provider.

func (*EnvironmentCredentialProvider) Descriptor

func (*EnvironmentCredentialProvider) Descriptor() ([]byte, []int)

Deprecated: Use EnvironmentCredentialProvider.ProtoReflect.Descriptor instead.

func (*EnvironmentCredentialProvider) ProtoMessage

func (*EnvironmentCredentialProvider) ProtoMessage()

func (*EnvironmentCredentialProvider) ProtoReflect

func (*EnvironmentCredentialProvider) Reset

func (x *EnvironmentCredentialProvider) Reset()

func (*EnvironmentCredentialProvider) String

func (*EnvironmentCredentialProvider) Validate

func (m *EnvironmentCredentialProvider) Validate() error

Validate checks the field values on EnvironmentCredentialProvider with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*EnvironmentCredentialProvider) ValidateAll

func (m *EnvironmentCredentialProvider) ValidateAll() error

ValidateAll checks the field values on EnvironmentCredentialProvider with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in EnvironmentCredentialProviderMultiError, or nil if none found.

type EnvironmentCredentialProviderMultiError

type EnvironmentCredentialProviderMultiError []error

EnvironmentCredentialProviderMultiError is an error wrapping multiple validation errors returned by EnvironmentCredentialProvider.ValidateAll() if the designated constraints aren't met.

func (EnvironmentCredentialProviderMultiError) AllErrors

AllErrors returns a list of validation violation errors.

func (EnvironmentCredentialProviderMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type EnvironmentCredentialProviderValidationError

type EnvironmentCredentialProviderValidationError struct {
	// contains filtered or unexported fields
}

EnvironmentCredentialProviderValidationError is the validation error returned by EnvironmentCredentialProvider.Validate if the designated constraints aren't met.

func (EnvironmentCredentialProviderValidationError) Cause

Cause function returns cause value.

func (EnvironmentCredentialProviderValidationError) Error

Error satisfies the builtin error interface

func (EnvironmentCredentialProviderValidationError) ErrorName

ErrorName returns error name.

func (EnvironmentCredentialProviderValidationError) Field

Field function returns field value.

func (EnvironmentCredentialProviderValidationError) Key

Key function returns key value.

func (EnvironmentCredentialProviderValidationError) Reason

Reason function returns reason value.

type IAMRolesAnywhereCredentialProvider

type IAMRolesAnywhereCredentialProvider struct {

	// The ARN of the role to assume via the IAM Roles Anywhere sessions API. See `Configure Roles <https://docs.aws.amazon.com/rolesanywhere/latest/userguide/getting-started.html#getting-started-step2>`_ for more details.
	RoleArn string `protobuf:"bytes,1,opt,name=role_arn,json=roleArn,proto3" json:"role_arn,omitempty"`
	// The certificate used for authenticating to the IAM Roles Anywhere service.
	// This certificate must match one configured in the IAM Roles Anywhere profile. See `Configure Roles <https://docs.aws.amazon.com/rolesanywhere/latest/userguide/getting-started.html#getting-started-step2>`_ for more details.
	Certificate *v3.DataSource `protobuf:"bytes,2,opt,name=certificate,proto3" json:"certificate,omitempty"`
	// The optional certificate chain, required when you are using a subordinate certificate authority for certificate issuance.
	// A certificate chain can contain a maximum of 5 elements, see `The IAM Roles Anywhere authentication process <https://docs.aws.amazon.com/rolesanywhere/latest/userguide/authentication.html>`_ for more details.
	CertificateChain *v3.DataSource `protobuf:"bytes,3,opt,name=certificate_chain,json=certificateChain,proto3" json:"certificate_chain,omitempty"`
	// The TLS private key matching the certificate provided.
	PrivateKey *v3.DataSource `protobuf:"bytes,4,opt,name=private_key,json=privateKey,proto3" json:"private_key,omitempty"`
	// The arn of the IAM Roles Anywhere trust anchor configured in your AWS account. A trust anchor in IAM Roles anywhere establishes
	// trust between your certificate authority (CA) and AWS. See `Establish trust <https://docs.aws.amazon.com/rolesanywhere/latest/userguide/getting-started.html#getting-started-step1>`_ for more details.
	TrustAnchorArn string `protobuf:"bytes,5,opt,name=trust_anchor_arn,json=trustAnchorArn,proto3" json:"trust_anchor_arn,omitempty"`
	// The IAM Roles Anywhere profile ARN configured in your AWS account.
	ProfileArn string `protobuf:"bytes,6,opt,name=profile_arn,json=profileArn,proto3" json:"profile_arn,omitempty"`
	// An optional role session name, used when identifying the role in subsequent AWS API calls.
	RoleSessionName string `protobuf:"bytes,7,opt,name=role_session_name,json=roleSessionName,proto3" json:"role_session_name,omitempty"`
	// An optional session duration, used when calculating the maximum time before vended credentials expire. This value cannot exceed the value configured
	// in the IAM Roles Anywhere profile and the resultant session duration is calculate by the formula `here <https://docs.aws.amazon.com/rolesanywhere/latest/userguide/authentication-create-session.html#credentials-object>`_.
	// If no session duration is provided here, the session duration is sourced from the IAM Roles Anywhere profile.
	SessionDuration *durationpb.Duration `protobuf:"bytes,8,opt,name=session_duration,json=sessionDuration,proto3" json:"session_duration,omitempty"`
	// contains filtered or unexported fields
}

Configuration to use `IAM Roles Anywhere <https://docs.aws.amazon.com/rolesanywhere/latest/userguide/introduction.html>`_ to retrieve AWS credentials. [#next-free-field: 9]

func (*IAMRolesAnywhereCredentialProvider) Descriptor

func (*IAMRolesAnywhereCredentialProvider) Descriptor() ([]byte, []int)

Deprecated: Use IAMRolesAnywhereCredentialProvider.ProtoReflect.Descriptor instead.

func (*IAMRolesAnywhereCredentialProvider) GetCertificate

func (x *IAMRolesAnywhereCredentialProvider) GetCertificate() *v3.DataSource

func (*IAMRolesAnywhereCredentialProvider) GetCertificateChain

func (x *IAMRolesAnywhereCredentialProvider) GetCertificateChain() *v3.DataSource

func (*IAMRolesAnywhereCredentialProvider) GetPrivateKey

func (x *IAMRolesAnywhereCredentialProvider) GetPrivateKey() *v3.DataSource

func (*IAMRolesAnywhereCredentialProvider) GetProfileArn

func (x *IAMRolesAnywhereCredentialProvider) GetProfileArn() string

func (*IAMRolesAnywhereCredentialProvider) GetRoleArn

func (*IAMRolesAnywhereCredentialProvider) GetRoleSessionName

func (x *IAMRolesAnywhereCredentialProvider) GetRoleSessionName() string

func (*IAMRolesAnywhereCredentialProvider) GetSessionDuration

func (x *IAMRolesAnywhereCredentialProvider) GetSessionDuration() *durationpb.Duration

func (*IAMRolesAnywhereCredentialProvider) GetTrustAnchorArn

func (x *IAMRolesAnywhereCredentialProvider) GetTrustAnchorArn() string

func (*IAMRolesAnywhereCredentialProvider) ProtoMessage

func (*IAMRolesAnywhereCredentialProvider) ProtoMessage()

func (*IAMRolesAnywhereCredentialProvider) ProtoReflect

func (*IAMRolesAnywhereCredentialProvider) Reset

func (*IAMRolesAnywhereCredentialProvider) String

func (*IAMRolesAnywhereCredentialProvider) Validate

Validate checks the field values on IAMRolesAnywhereCredentialProvider with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*IAMRolesAnywhereCredentialProvider) ValidateAll

func (m *IAMRolesAnywhereCredentialProvider) ValidateAll() error

ValidateAll checks the field values on IAMRolesAnywhereCredentialProvider with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in IAMRolesAnywhereCredentialProviderMultiError, or nil if none found.

type IAMRolesAnywhereCredentialProviderMultiError

type IAMRolesAnywhereCredentialProviderMultiError []error

IAMRolesAnywhereCredentialProviderMultiError is an error wrapping multiple validation errors returned by IAMRolesAnywhereCredentialProvider.ValidateAll() if the designated constraints aren't met.

func (IAMRolesAnywhereCredentialProviderMultiError) AllErrors

AllErrors returns a list of validation violation errors.

func (IAMRolesAnywhereCredentialProviderMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type IAMRolesAnywhereCredentialProviderValidationError

type IAMRolesAnywhereCredentialProviderValidationError struct {
	// contains filtered or unexported fields
}

IAMRolesAnywhereCredentialProviderValidationError is the validation error returned by IAMRolesAnywhereCredentialProvider.Validate if the designated constraints aren't met.

func (IAMRolesAnywhereCredentialProviderValidationError) Cause

Cause function returns cause value.

func (IAMRolesAnywhereCredentialProviderValidationError) Error

Error satisfies the builtin error interface

func (IAMRolesAnywhereCredentialProviderValidationError) ErrorName

ErrorName returns error name.

func (IAMRolesAnywhereCredentialProviderValidationError) Field

Field function returns field value.

func (IAMRolesAnywhereCredentialProviderValidationError) Key

Key function returns key value.

func (IAMRolesAnywhereCredentialProviderValidationError) Reason

Reason function returns reason value.

type InlineCredentialProvider

type InlineCredentialProvider struct {

	// The AWS access key ID.
	AccessKeyId string `protobuf:"bytes,1,opt,name=access_key_id,json=accessKeyId,proto3" json:"access_key_id,omitempty"`
	// The AWS secret access key.
	SecretAccessKey string `protobuf:"bytes,2,opt,name=secret_access_key,json=secretAccessKey,proto3" json:"secret_access_key,omitempty"`
	// The AWS session token. This is optional.
	SessionToken string `protobuf:"bytes,3,opt,name=session_token,json=sessionToken,proto3" json:"session_token,omitempty"`
	// contains filtered or unexported fields
}

Configuration to use an inline AWS credential. This is an equivalent to setting the well-known environment variables “AWS_ACCESS_KEY_ID“, “AWS_SECRET_ACCESS_KEY“, and the optional “AWS_SESSION_TOKEN“.

func (*InlineCredentialProvider) Descriptor

func (*InlineCredentialProvider) Descriptor() ([]byte, []int)

Deprecated: Use InlineCredentialProvider.ProtoReflect.Descriptor instead.

func (*InlineCredentialProvider) GetAccessKeyId

func (x *InlineCredentialProvider) GetAccessKeyId() string

func (*InlineCredentialProvider) GetSecretAccessKey

func (x *InlineCredentialProvider) GetSecretAccessKey() string

func (*InlineCredentialProvider) GetSessionToken

func (x *InlineCredentialProvider) GetSessionToken() string

func (*InlineCredentialProvider) ProtoMessage

func (*InlineCredentialProvider) ProtoMessage()

func (*InlineCredentialProvider) ProtoReflect

func (x *InlineCredentialProvider) ProtoReflect() protoreflect.Message

func (*InlineCredentialProvider) Reset

func (x *InlineCredentialProvider) Reset()

func (*InlineCredentialProvider) String

func (x *InlineCredentialProvider) String() string

func (*InlineCredentialProvider) Validate

func (m *InlineCredentialProvider) Validate() error

Validate checks the field values on InlineCredentialProvider with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*InlineCredentialProvider) ValidateAll

func (m *InlineCredentialProvider) ValidateAll() error

ValidateAll checks the field values on InlineCredentialProvider with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in InlineCredentialProviderMultiError, or nil if none found.

type InlineCredentialProviderMultiError

type InlineCredentialProviderMultiError []error

InlineCredentialProviderMultiError is an error wrapping multiple validation errors returned by InlineCredentialProvider.ValidateAll() if the designated constraints aren't met.

func (InlineCredentialProviderMultiError) AllErrors

func (m InlineCredentialProviderMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (InlineCredentialProviderMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type InlineCredentialProviderValidationError

type InlineCredentialProviderValidationError struct {
	// contains filtered or unexported fields
}

InlineCredentialProviderValidationError is the validation error returned by InlineCredentialProvider.Validate if the designated constraints aren't met.

func (InlineCredentialProviderValidationError) Cause

Cause function returns cause value.

func (InlineCredentialProviderValidationError) Error

Error satisfies the builtin error interface

func (InlineCredentialProviderValidationError) ErrorName

ErrorName returns error name.

func (InlineCredentialProviderValidationError) Field

Field function returns field value.

func (InlineCredentialProviderValidationError) Key

Key function returns key value.

func (InlineCredentialProviderValidationError) Reason

Reason function returns reason value.

type InstanceProfileCredentialProvider

type InstanceProfileCredentialProvider struct {
	// contains filtered or unexported fields
}

The Instance Profile Credential Provider has no configurable parameters, but listing it in a custom credential provider chain will enable this credential provider.

func (*InstanceProfileCredentialProvider) Descriptor

func (*InstanceProfileCredentialProvider) Descriptor() ([]byte, []int)

Deprecated: Use InstanceProfileCredentialProvider.ProtoReflect.Descriptor instead.

func (*InstanceProfileCredentialProvider) ProtoMessage

func (*InstanceProfileCredentialProvider) ProtoMessage()

func (*InstanceProfileCredentialProvider) ProtoReflect

func (*InstanceProfileCredentialProvider) Reset

func (*InstanceProfileCredentialProvider) String

func (*InstanceProfileCredentialProvider) Validate

Validate checks the field values on InstanceProfileCredentialProvider with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*InstanceProfileCredentialProvider) ValidateAll

func (m *InstanceProfileCredentialProvider) ValidateAll() error

ValidateAll checks the field values on InstanceProfileCredentialProvider with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in InstanceProfileCredentialProviderMultiError, or nil if none found.

type InstanceProfileCredentialProviderMultiError

type InstanceProfileCredentialProviderMultiError []error

InstanceProfileCredentialProviderMultiError is an error wrapping multiple validation errors returned by InstanceProfileCredentialProvider.ValidateAll() if the designated constraints aren't met.

func (InstanceProfileCredentialProviderMultiError) AllErrors

AllErrors returns a list of validation violation errors.

func (InstanceProfileCredentialProviderMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type InstanceProfileCredentialProviderValidationError

type InstanceProfileCredentialProviderValidationError struct {
	// contains filtered or unexported fields
}

InstanceProfileCredentialProviderValidationError is the validation error returned by InstanceProfileCredentialProvider.Validate if the designated constraints aren't met.

func (InstanceProfileCredentialProviderValidationError) Cause

Cause function returns cause value.

func (InstanceProfileCredentialProviderValidationError) Error

Error satisfies the builtin error interface

func (InstanceProfileCredentialProviderValidationError) ErrorName

ErrorName returns error name.

func (InstanceProfileCredentialProviderValidationError) Field

Field function returns field value.

func (InstanceProfileCredentialProviderValidationError) Key

Key function returns key value.

func (InstanceProfileCredentialProviderValidationError) Reason

Reason function returns reason value.

Source Files

credential_provider.pb.go credential_provider.pb.validate.go

Version
v1.37.0 (latest)
Published
Jan 13, 2026
Platform
linux/amd64
Imports
21 packages
Last checked
1 hour ago

Tools for package owners.