package file_based_metadatav3

import "github.com/envoyproxy/go-control-plane/envoy/extensions/grpc_service/call_credentials/file_based_metadata/v3"

Index

Variables

var File_envoy_extensions_grpc_service_call_credentials_file_based_metadata_v3_file_based_metadata_credentials_proto protoreflect.FileDescriptor

Types

type FileBasedMetadataCallCredentials

type FileBasedMetadataCallCredentials struct {

	// Location or inline data of secret to use for authentication of the Google gRPC connection
	// this secret will be attached to a header of the gRPC connection
	SecretData *v3.DataSource `protobuf:"bytes,1,opt,name=secret_data,json=secretData,proto3" json:"secret_data,omitempty"`
	// Metadata header key to use for sending the secret data
	// if no header key is set, "authorization" header will be used
	HeaderKey string `protobuf:"bytes,2,opt,name=header_key,json=headerKey,proto3" json:"header_key,omitempty"`
	// Prefix to prepend to the secret in the metadata header
	// if no prefix is set, the default is to use no prefix
	HeaderPrefix string `protobuf:"bytes,3,opt,name=header_prefix,json=headerPrefix,proto3" json:"header_prefix,omitempty"`
	// contains filtered or unexported fields
}

[#not-implemented-hide:]

func (*FileBasedMetadataCallCredentials) Descriptor

func (*FileBasedMetadataCallCredentials) Descriptor() ([]byte, []int)

Deprecated: Use FileBasedMetadataCallCredentials.ProtoReflect.Descriptor instead.

func (*FileBasedMetadataCallCredentials) GetHeaderKey

func (x *FileBasedMetadataCallCredentials) GetHeaderKey() string

func (*FileBasedMetadataCallCredentials) GetHeaderPrefix

func (x *FileBasedMetadataCallCredentials) GetHeaderPrefix() string

func (*FileBasedMetadataCallCredentials) GetSecretData

func (x *FileBasedMetadataCallCredentials) GetSecretData() *v3.DataSource

func (*FileBasedMetadataCallCredentials) ProtoMessage

func (*FileBasedMetadataCallCredentials) ProtoMessage()

func (*FileBasedMetadataCallCredentials) ProtoReflect

func (*FileBasedMetadataCallCredentials) Reset

func (*FileBasedMetadataCallCredentials) String

func (*FileBasedMetadataCallCredentials) Validate

Validate checks the field values on FileBasedMetadataCallCredentials with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*FileBasedMetadataCallCredentials) ValidateAll

func (m *FileBasedMetadataCallCredentials) ValidateAll() error

ValidateAll checks the field values on FileBasedMetadataCallCredentials with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in FileBasedMetadataCallCredentialsMultiError, or nil if none found.

type FileBasedMetadataCallCredentialsMultiError

type FileBasedMetadataCallCredentialsMultiError []error

FileBasedMetadataCallCredentialsMultiError is an error wrapping multiple validation errors returned by FileBasedMetadataCallCredentials.ValidateAll() if the designated constraints aren't met.

func (FileBasedMetadataCallCredentialsMultiError) AllErrors

AllErrors returns a list of validation violation errors.

func (FileBasedMetadataCallCredentialsMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type FileBasedMetadataCallCredentialsValidationError

type FileBasedMetadataCallCredentialsValidationError struct {
	// contains filtered or unexported fields
}

FileBasedMetadataCallCredentialsValidationError is the validation error returned by FileBasedMetadataCallCredentials.Validate if the designated constraints aren't met.

func (FileBasedMetadataCallCredentialsValidationError) Cause

Cause function returns cause value.

func (FileBasedMetadataCallCredentialsValidationError) Error

Error satisfies the builtin error interface

func (FileBasedMetadataCallCredentialsValidationError) ErrorName

ErrorName returns error name.

func (FileBasedMetadataCallCredentialsValidationError) Field

Field function returns field value.

func (FileBasedMetadataCallCredentialsValidationError) Key

Key function returns key value.

func (FileBasedMetadataCallCredentialsValidationError) Reason

Reason function returns reason value.

Source Files

file_based_metadata_credentials.pb.go file_based_metadata_credentials.pb.validate.go

Version
v1.37.0 (latest)
Published
Jan 13, 2026
Platform
linux/amd64
Imports
19 packages
Last checked
3 hours ago

Tools for package owners.