package google_compute_enginev3
import "github.com/envoyproxy/go-control-plane/envoy/extensions/grpc_service/call_credentials/google_compute_engine/v3"
Index ¶
- Variables
- type GoogleComputeEngineCredentials
- func (*GoogleComputeEngineCredentials) Descriptor() ([]byte, []int)
- func (*GoogleComputeEngineCredentials) ProtoMessage()
- func (x *GoogleComputeEngineCredentials) ProtoReflect() protoreflect.Message
- func (x *GoogleComputeEngineCredentials) Reset()
- func (x *GoogleComputeEngineCredentials) String() string
- func (m *GoogleComputeEngineCredentials) Validate() error
- func (m *GoogleComputeEngineCredentials) ValidateAll() error
- type GoogleComputeEngineCredentialsMultiError
- func (m GoogleComputeEngineCredentialsMultiError) AllErrors() []error
- func (m GoogleComputeEngineCredentialsMultiError) Error() string
- type GoogleComputeEngineCredentialsValidationError
- func (e GoogleComputeEngineCredentialsValidationError) Cause() error
- func (e GoogleComputeEngineCredentialsValidationError) Error() string
- func (e GoogleComputeEngineCredentialsValidationError) ErrorName() string
- func (e GoogleComputeEngineCredentialsValidationError) Field() string
- func (e GoogleComputeEngineCredentialsValidationError) Key() bool
- func (e GoogleComputeEngineCredentialsValidationError) Reason() string
Variables ¶
var File_envoy_extensions_grpc_service_call_credentials_google_compute_engine_v3_google_compute_engine_credentials_proto protoreflect.FileDescriptor
Types ¶
type GoogleComputeEngineCredentials ¶
type GoogleComputeEngineCredentials struct {
// contains filtered or unexported fields
}
[#not-implemented-hide:]
func (*GoogleComputeEngineCredentials) Descriptor ¶
func (*GoogleComputeEngineCredentials) Descriptor() ([]byte, []int)
Deprecated: Use GoogleComputeEngineCredentials.ProtoReflect.Descriptor instead.
func (*GoogleComputeEngineCredentials) ProtoMessage ¶
func (*GoogleComputeEngineCredentials) ProtoMessage()
func (*GoogleComputeEngineCredentials) ProtoReflect ¶
func (x *GoogleComputeEngineCredentials) ProtoReflect() protoreflect.Message
func (*GoogleComputeEngineCredentials) Reset ¶
func (x *GoogleComputeEngineCredentials) Reset()
func (*GoogleComputeEngineCredentials) String ¶
func (x *GoogleComputeEngineCredentials) String() string
func (*GoogleComputeEngineCredentials) Validate ¶
func (m *GoogleComputeEngineCredentials) Validate() error
Validate checks the field values on GoogleComputeEngineCredentials with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*GoogleComputeEngineCredentials) ValidateAll ¶
func (m *GoogleComputeEngineCredentials) ValidateAll() error
ValidateAll checks the field values on GoogleComputeEngineCredentials with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in GoogleComputeEngineCredentialsMultiError, or nil if none found.
type GoogleComputeEngineCredentialsMultiError ¶
type GoogleComputeEngineCredentialsMultiError []error
GoogleComputeEngineCredentialsMultiError is an error wrapping multiple validation errors returned by GoogleComputeEngineCredentials.ValidateAll() if the designated constraints aren't met.
func (GoogleComputeEngineCredentialsMultiError) AllErrors ¶
func (m GoogleComputeEngineCredentialsMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (GoogleComputeEngineCredentialsMultiError) Error ¶
func (m GoogleComputeEngineCredentialsMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type GoogleComputeEngineCredentialsValidationError ¶
type GoogleComputeEngineCredentialsValidationError struct {
// contains filtered or unexported fields
}
GoogleComputeEngineCredentialsValidationError is the validation error returned by GoogleComputeEngineCredentials.Validate if the designated constraints aren't met.
func (GoogleComputeEngineCredentialsValidationError) Cause ¶
func (e GoogleComputeEngineCredentialsValidationError) Cause() error
Cause function returns cause value.
func (GoogleComputeEngineCredentialsValidationError) Error ¶
func (e GoogleComputeEngineCredentialsValidationError) Error() string
Error satisfies the builtin error interface
func (GoogleComputeEngineCredentialsValidationError) ErrorName ¶
func (e GoogleComputeEngineCredentialsValidationError) ErrorName() string
ErrorName returns error name.
func (GoogleComputeEngineCredentialsValidationError) Field ¶
func (e GoogleComputeEngineCredentialsValidationError) Field() string
Field function returns field value.
func (GoogleComputeEngineCredentialsValidationError) Key ¶
func (e GoogleComputeEngineCredentialsValidationError) Key() bool
Key function returns key value.
func (GoogleComputeEngineCredentialsValidationError) Reason ¶
func (e GoogleComputeEngineCredentialsValidationError) Reason() string
Reason function returns reason value.
Source Files ¶
google_compute_engine_credentials.pb.go google_compute_engine_credentials.pb.validate.go
- Version
- v1.37.0 (latest)
- Published
- Jan 13, 2026
- Platform
- linux/amd64
- Imports
- 18 packages
- Last checked
- 3 hours ago –
Tools for package owners.