package google_refresh_tokenv3

import "github.com/envoyproxy/go-control-plane/envoy/extensions/grpc_service/call_credentials/google_refresh_token/v3"

Index

Variables

var File_envoy_extensions_grpc_service_call_credentials_google_refresh_token_v3_google_refresh_token_credentials_proto protoreflect.FileDescriptor

Types

type GoogleRefreshTokenCredentials

type GoogleRefreshTokenCredentials struct {

	// JSON refresh token.
	Token string `protobuf:"bytes,1,opt,name=token,proto3" json:"token,omitempty"`
	// contains filtered or unexported fields
}

[#not-implemented-hide:]

func (*GoogleRefreshTokenCredentials) Descriptor

func (*GoogleRefreshTokenCredentials) Descriptor() ([]byte, []int)

Deprecated: Use GoogleRefreshTokenCredentials.ProtoReflect.Descriptor instead.

func (*GoogleRefreshTokenCredentials) GetToken

func (x *GoogleRefreshTokenCredentials) GetToken() string

func (*GoogleRefreshTokenCredentials) ProtoMessage

func (*GoogleRefreshTokenCredentials) ProtoMessage()

func (*GoogleRefreshTokenCredentials) ProtoReflect

func (*GoogleRefreshTokenCredentials) Reset

func (x *GoogleRefreshTokenCredentials) Reset()

func (*GoogleRefreshTokenCredentials) String

func (*GoogleRefreshTokenCredentials) Validate

func (m *GoogleRefreshTokenCredentials) Validate() error

Validate checks the field values on GoogleRefreshTokenCredentials with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*GoogleRefreshTokenCredentials) ValidateAll

func (m *GoogleRefreshTokenCredentials) ValidateAll() error

ValidateAll checks the field values on GoogleRefreshTokenCredentials with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in GoogleRefreshTokenCredentialsMultiError, or nil if none found.

type GoogleRefreshTokenCredentialsMultiError

type GoogleRefreshTokenCredentialsMultiError []error

GoogleRefreshTokenCredentialsMultiError is an error wrapping multiple validation errors returned by GoogleRefreshTokenCredentials.ValidateAll() if the designated constraints aren't met.

func (GoogleRefreshTokenCredentialsMultiError) AllErrors

AllErrors returns a list of validation violation errors.

func (GoogleRefreshTokenCredentialsMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type GoogleRefreshTokenCredentialsValidationError

type GoogleRefreshTokenCredentialsValidationError struct {
	// contains filtered or unexported fields
}

GoogleRefreshTokenCredentialsValidationError is the validation error returned by GoogleRefreshTokenCredentials.Validate if the designated constraints aren't met.

func (GoogleRefreshTokenCredentialsValidationError) Cause

Cause function returns cause value.

func (GoogleRefreshTokenCredentialsValidationError) Error

Error satisfies the builtin error interface

func (GoogleRefreshTokenCredentialsValidationError) ErrorName

ErrorName returns error name.

func (GoogleRefreshTokenCredentialsValidationError) Field

Field function returns field value.

func (GoogleRefreshTokenCredentialsValidationError) Key

Key function returns key value.

func (GoogleRefreshTokenCredentialsValidationError) Reason

Reason function returns reason value.

Source Files

google_refresh_token_credentials.pb.go google_refresh_token_credentials.pb.validate.go

Version
v1.37.0 (latest)
Published
Jan 13, 2026
Platform
linux/amd64
Imports
18 packages
Last checked
6 hours ago

Tools for package owners.