package google_defaultv3

import "github.com/envoyproxy/go-control-plane/envoy/extensions/grpc_service/channel_credentials/google_default/v3"

Index

Variables

var File_envoy_extensions_grpc_service_channel_credentials_google_default_v3_google_default_credentials_proto protoreflect.FileDescriptor

Types

type GoogleDefaultCredentials

type GoogleDefaultCredentials struct {
	// contains filtered or unexported fields
}

[#not-implemented-hide:]

func (*GoogleDefaultCredentials) Descriptor

func (*GoogleDefaultCredentials) Descriptor() ([]byte, []int)

Deprecated: Use GoogleDefaultCredentials.ProtoReflect.Descriptor instead.

func (*GoogleDefaultCredentials) ProtoMessage

func (*GoogleDefaultCredentials) ProtoMessage()

func (*GoogleDefaultCredentials) ProtoReflect

func (x *GoogleDefaultCredentials) ProtoReflect() protoreflect.Message

func (*GoogleDefaultCredentials) Reset

func (x *GoogleDefaultCredentials) Reset()

func (*GoogleDefaultCredentials) String

func (x *GoogleDefaultCredentials) String() string

func (*GoogleDefaultCredentials) Validate

func (m *GoogleDefaultCredentials) Validate() error

Validate checks the field values on GoogleDefaultCredentials with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*GoogleDefaultCredentials) ValidateAll

func (m *GoogleDefaultCredentials) ValidateAll() error

ValidateAll checks the field values on GoogleDefaultCredentials with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in GoogleDefaultCredentialsMultiError, or nil if none found.

type GoogleDefaultCredentialsMultiError

type GoogleDefaultCredentialsMultiError []error

GoogleDefaultCredentialsMultiError is an error wrapping multiple validation errors returned by GoogleDefaultCredentials.ValidateAll() if the designated constraints aren't met.

func (GoogleDefaultCredentialsMultiError) AllErrors

func (m GoogleDefaultCredentialsMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (GoogleDefaultCredentialsMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type GoogleDefaultCredentialsValidationError

type GoogleDefaultCredentialsValidationError struct {
	// contains filtered or unexported fields
}

GoogleDefaultCredentialsValidationError is the validation error returned by GoogleDefaultCredentials.Validate if the designated constraints aren't met.

func (GoogleDefaultCredentialsValidationError) Cause

Cause function returns cause value.

func (GoogleDefaultCredentialsValidationError) Error

Error satisfies the builtin error interface

func (GoogleDefaultCredentialsValidationError) ErrorName

ErrorName returns error name.

func (GoogleDefaultCredentialsValidationError) Field

Field function returns field value.

func (GoogleDefaultCredentialsValidationError) Key

Key function returns key value.

func (GoogleDefaultCredentialsValidationError) Reason

Reason function returns reason value.

Source Files

google_default_credentials.pb.go google_default_credentials.pb.validate.go

Version
v1.37.0 (latest)
Published
Jan 13, 2026
Platform
linux/amd64
Imports
18 packages
Last checked
4 hours ago

Tools for package owners.