package insecurev3

import "github.com/envoyproxy/go-control-plane/envoy/extensions/grpc_service/channel_credentials/insecure/v3"

Index

Variables

var File_envoy_extensions_grpc_service_channel_credentials_insecure_v3_insecure_credentials_proto protoreflect.FileDescriptor

Types

type InsecureCredentials

type InsecureCredentials struct {
	// contains filtered or unexported fields
}

[#not-implemented-hide:]

func (*InsecureCredentials) Descriptor

func (*InsecureCredentials) Descriptor() ([]byte, []int)

Deprecated: Use InsecureCredentials.ProtoReflect.Descriptor instead.

func (*InsecureCredentials) ProtoMessage

func (*InsecureCredentials) ProtoMessage()

func (*InsecureCredentials) ProtoReflect

func (x *InsecureCredentials) ProtoReflect() protoreflect.Message

func (*InsecureCredentials) Reset

func (x *InsecureCredentials) Reset()

func (*InsecureCredentials) String

func (x *InsecureCredentials) String() string

func (*InsecureCredentials) Validate

func (m *InsecureCredentials) Validate() error

Validate checks the field values on InsecureCredentials with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*InsecureCredentials) ValidateAll

func (m *InsecureCredentials) ValidateAll() error

ValidateAll checks the field values on InsecureCredentials with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in InsecureCredentialsMultiError, or nil if none found.

type InsecureCredentialsMultiError

type InsecureCredentialsMultiError []error

InsecureCredentialsMultiError is an error wrapping multiple validation errors returned by InsecureCredentials.ValidateAll() if the designated constraints aren't met.

func (InsecureCredentialsMultiError) AllErrors

func (m InsecureCredentialsMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (InsecureCredentialsMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type InsecureCredentialsValidationError

type InsecureCredentialsValidationError struct {
	// contains filtered or unexported fields
}

InsecureCredentialsValidationError is the validation error returned by InsecureCredentials.Validate if the designated constraints aren't met.

func (InsecureCredentialsValidationError) Cause

Cause function returns cause value.

func (InsecureCredentialsValidationError) Error

Error satisfies the builtin error interface

func (InsecureCredentialsValidationError) ErrorName

ErrorName returns error name.

func (InsecureCredentialsValidationError) Field

Field function returns field value.

func (InsecureCredentialsValidationError) Key

Key function returns key value.

func (InsecureCredentialsValidationError) Reason

Reason function returns reason value.

Source Files

insecure_credentials.pb.go insecure_credentials.pb.validate.go

Version
v1.37.0 (latest)
Published
Jan 13, 2026
Platform
linux/amd64
Imports
18 packages
Last checked
6 hours ago

Tools for package owners.