package statsv3

import "github.com/envoyproxy/go-control-plane/envoy/extensions/matching/common_inputs/stats/v3"

Index

Variables

var File_envoy_extensions_matching_common_inputs_stats_v3_stats_proto protoreflect.FileDescriptor

Types

type StatFullNameMatchInput

type StatFullNameMatchInput struct {
	// contains filtered or unexported fields
}

Specifies the way to match stats with full name.

func (*StatFullNameMatchInput) Descriptor

func (*StatFullNameMatchInput) Descriptor() ([]byte, []int)

Deprecated: Use StatFullNameMatchInput.ProtoReflect.Descriptor instead.

func (*StatFullNameMatchInput) ProtoMessage

func (*StatFullNameMatchInput) ProtoMessage()

func (*StatFullNameMatchInput) ProtoReflect

func (x *StatFullNameMatchInput) ProtoReflect() protoreflect.Message

func (*StatFullNameMatchInput) Reset

func (x *StatFullNameMatchInput) Reset()

func (*StatFullNameMatchInput) String

func (x *StatFullNameMatchInput) String() string

func (*StatFullNameMatchInput) Validate

func (m *StatFullNameMatchInput) Validate() error

Validate checks the field values on StatFullNameMatchInput with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*StatFullNameMatchInput) ValidateAll

func (m *StatFullNameMatchInput) ValidateAll() error

ValidateAll checks the field values on StatFullNameMatchInput with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in StatFullNameMatchInputMultiError, or nil if none found.

type StatFullNameMatchInputMultiError

type StatFullNameMatchInputMultiError []error

StatFullNameMatchInputMultiError is an error wrapping multiple validation errors returned by StatFullNameMatchInput.ValidateAll() if the designated constraints aren't met.

func (StatFullNameMatchInputMultiError) AllErrors

func (m StatFullNameMatchInputMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (StatFullNameMatchInputMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type StatFullNameMatchInputValidationError

type StatFullNameMatchInputValidationError struct {
	// contains filtered or unexported fields
}

StatFullNameMatchInputValidationError is the validation error returned by StatFullNameMatchInput.Validate if the designated constraints aren't met.

func (StatFullNameMatchInputValidationError) Cause

Cause function returns cause value.

func (StatFullNameMatchInputValidationError) Error

Error satisfies the builtin error interface

func (StatFullNameMatchInputValidationError) ErrorName

ErrorName returns error name.

func (StatFullNameMatchInputValidationError) Field

Field function returns field value.

func (StatFullNameMatchInputValidationError) Key

Key function returns key value.

func (StatFullNameMatchInputValidationError) Reason

Reason function returns reason value.

Source Files

stats.pb.go stats.pb.validate.go

Version
v1.37.0 (latest)
Published
Jan 13, 2026
Platform
linux/amd64
Imports
18 packages
Last checked
12 hours ago

Tools for package owners.