package socket_interfacev3

import "github.com/envoyproxy/go-control-plane/envoy/extensions/network/socket_interface/v3"

Index

Variables

var File_envoy_extensions_network_socket_interface_v3_default_socket_interface_proto protoreflect.FileDescriptor

Types

type DefaultSocketInterface

type DefaultSocketInterface struct {

	// io_uring options. io_uring is only valid in Linux with at least kernel version 5.11. Otherwise,
	// Envoy will fall back to use the default socket API. If not set then io_uring will not be
	// enabled.
	IoUringOptions *IoUringOptions `protobuf:"bytes,1,opt,name=io_uring_options,json=ioUringOptions,proto3" json:"io_uring_options,omitempty"`
	// contains filtered or unexported fields
}

Configuration for default socket interface that relies on OS dependent syscall to create sockets.

func (*DefaultSocketInterface) Descriptor

func (*DefaultSocketInterface) Descriptor() ([]byte, []int)

Deprecated: Use DefaultSocketInterface.ProtoReflect.Descriptor instead.

func (*DefaultSocketInterface) GetIoUringOptions

func (x *DefaultSocketInterface) GetIoUringOptions() *IoUringOptions

func (*DefaultSocketInterface) ProtoMessage

func (*DefaultSocketInterface) ProtoMessage()

func (*DefaultSocketInterface) ProtoReflect

func (x *DefaultSocketInterface) ProtoReflect() protoreflect.Message

func (*DefaultSocketInterface) Reset

func (x *DefaultSocketInterface) Reset()

func (*DefaultSocketInterface) String

func (x *DefaultSocketInterface) String() string

func (*DefaultSocketInterface) Validate

func (m *DefaultSocketInterface) Validate() error

Validate checks the field values on DefaultSocketInterface with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*DefaultSocketInterface) ValidateAll

func (m *DefaultSocketInterface) ValidateAll() error

ValidateAll checks the field values on DefaultSocketInterface with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in DefaultSocketInterfaceMultiError, or nil if none found.

type DefaultSocketInterfaceMultiError

type DefaultSocketInterfaceMultiError []error

DefaultSocketInterfaceMultiError is an error wrapping multiple validation errors returned by DefaultSocketInterface.ValidateAll() if the designated constraints aren't met.

func (DefaultSocketInterfaceMultiError) AllErrors

func (m DefaultSocketInterfaceMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (DefaultSocketInterfaceMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type DefaultSocketInterfaceValidationError

type DefaultSocketInterfaceValidationError struct {
	// contains filtered or unexported fields
}

DefaultSocketInterfaceValidationError is the validation error returned by DefaultSocketInterface.Validate if the designated constraints aren't met.

func (DefaultSocketInterfaceValidationError) Cause

Cause function returns cause value.

func (DefaultSocketInterfaceValidationError) Error

Error satisfies the builtin error interface

func (DefaultSocketInterfaceValidationError) ErrorName

ErrorName returns error name.

func (DefaultSocketInterfaceValidationError) Field

Field function returns field value.

func (DefaultSocketInterfaceValidationError) Key

Key function returns key value.

func (DefaultSocketInterfaceValidationError) Reason

Reason function returns reason value.

type IoUringOptions

type IoUringOptions struct {

	// The size for io_uring submission queues (SQ). io_uring is built with a fixed size in each
	// thread during configuration, and each io_uring operation creates a submission queue
	// entry (SQE). The default is 1000.
	IoUringSize *wrapperspb.UInt32Value `protobuf:"bytes,1,opt,name=io_uring_size,json=ioUringSize,proto3" json:"io_uring_size,omitempty"`
	// Enable io_uring submission queue polling (SQPOLL). io_uring SQPOLL mode polls all SQEs in the
	// SQ in the kernel thread. io_uring SQPOLL mode may reduce latency and increase CPU usage as a
	// cost. The default is false.
	EnableSubmissionQueuePolling bool `protobuf:"varint,2,opt,name=enable_submission_queue_polling,json=enableSubmissionQueuePolling,proto3" json:"enable_submission_queue_polling,omitempty"`
	// The size of an io_uring socket's read buffer. Each io_uring read operation will allocate a
	// buffer of the given size. If the given buffer is too small, the socket will have read multiple
	// times for all the data. The default is 8192.
	ReadBufferSize *wrapperspb.UInt32Value `protobuf:"bytes,3,opt,name=read_buffer_size,json=readBufferSize,proto3" json:"read_buffer_size,omitempty"`
	// The write timeout of an io_uring socket on closing in ms. io_uring writes and closes
	// asynchronously. If the remote stops reading, the io_uring write operation may never complete.
	// The operation is canceled and the socket is closed after the timeout. The default is 1000.
	WriteTimeoutMs *wrapperspb.UInt32Value `protobuf:"bytes,4,opt,name=write_timeout_ms,json=writeTimeoutMs,proto3" json:"write_timeout_ms,omitempty"`
	// contains filtered or unexported fields
}

func (*IoUringOptions) Descriptor

func (*IoUringOptions) Descriptor() ([]byte, []int)

Deprecated: Use IoUringOptions.ProtoReflect.Descriptor instead.

func (*IoUringOptions) GetEnableSubmissionQueuePolling

func (x *IoUringOptions) GetEnableSubmissionQueuePolling() bool

func (*IoUringOptions) GetIoUringSize

func (x *IoUringOptions) GetIoUringSize() *wrapperspb.UInt32Value

func (*IoUringOptions) GetReadBufferSize

func (x *IoUringOptions) GetReadBufferSize() *wrapperspb.UInt32Value

func (*IoUringOptions) GetWriteTimeoutMs

func (x *IoUringOptions) GetWriteTimeoutMs() *wrapperspb.UInt32Value

func (*IoUringOptions) ProtoMessage

func (*IoUringOptions) ProtoMessage()

func (*IoUringOptions) ProtoReflect

func (x *IoUringOptions) ProtoReflect() protoreflect.Message

func (*IoUringOptions) Reset

func (x *IoUringOptions) Reset()

func (*IoUringOptions) String

func (x *IoUringOptions) String() string

func (*IoUringOptions) Validate

func (m *IoUringOptions) Validate() error

Validate checks the field values on IoUringOptions with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*IoUringOptions) ValidateAll

func (m *IoUringOptions) ValidateAll() error

ValidateAll checks the field values on IoUringOptions with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in IoUringOptionsMultiError, or nil if none found.

type IoUringOptionsMultiError

type IoUringOptionsMultiError []error

IoUringOptionsMultiError is an error wrapping multiple validation errors returned by IoUringOptions.ValidateAll() if the designated constraints aren't met.

func (IoUringOptionsMultiError) AllErrors

func (m IoUringOptionsMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (IoUringOptionsMultiError) Error

func (m IoUringOptionsMultiError) Error() string

Error returns a concatenation of all the error messages it wraps.

type IoUringOptionsValidationError

type IoUringOptionsValidationError struct {
	// contains filtered or unexported fields
}

IoUringOptionsValidationError is the validation error returned by IoUringOptions.Validate if the designated constraints aren't met.

func (IoUringOptionsValidationError) Cause

Cause function returns cause value.

func (IoUringOptionsValidationError) Error

Error satisfies the builtin error interface

func (IoUringOptionsValidationError) ErrorName

func (e IoUringOptionsValidationError) ErrorName() string

ErrorName returns error name.

func (IoUringOptionsValidationError) Field

Field function returns field value.

func (IoUringOptionsValidationError) Key

Key function returns key value.

func (IoUringOptionsValidationError) Reason

Reason function returns reason value.

Source Files

default_socket_interface.pb.go default_socket_interface.pb.validate.go

Version
v1.37.0 (latest)
Published
Jan 13, 2026
Platform
linux/amd64
Imports
19 packages
Last checked
1 hour ago

Tools for package owners.