package cgroup_memoryv3

import "github.com/envoyproxy/go-control-plane/envoy/extensions/resource_monitors/cgroup_memory/v3"

Index

Variables

var File_envoy_extensions_resource_monitors_cgroup_memory_v3_cgroup_memory_proto protoreflect.FileDescriptor

Types

type CgroupMemoryConfig

type CgroupMemoryConfig struct {

	// Optional max memory limit in bytes used for memory pressure calculations.
	// If set, this value is used as an upper bound on the memory limit, taking the minimum
	// between this value and the system's cgroup memory limit. If not set, the system's
	// cgroup memory limit is always used.
	MaxMemoryBytes uint64 `protobuf:"varint,1,opt,name=max_memory_bytes,json=maxMemoryBytes,proto3" json:"max_memory_bytes,omitempty"`
	// contains filtered or unexported fields
}

func (*CgroupMemoryConfig) Descriptor

func (*CgroupMemoryConfig) Descriptor() ([]byte, []int)

Deprecated: Use CgroupMemoryConfig.ProtoReflect.Descriptor instead.

func (*CgroupMemoryConfig) GetMaxMemoryBytes

func (x *CgroupMemoryConfig) GetMaxMemoryBytes() uint64

func (*CgroupMemoryConfig) ProtoMessage

func (*CgroupMemoryConfig) ProtoMessage()

func (*CgroupMemoryConfig) ProtoReflect

func (x *CgroupMemoryConfig) ProtoReflect() protoreflect.Message

func (*CgroupMemoryConfig) Reset

func (x *CgroupMemoryConfig) Reset()

func (*CgroupMemoryConfig) String

func (x *CgroupMemoryConfig) String() string

func (*CgroupMemoryConfig) Validate

func (m *CgroupMemoryConfig) Validate() error

Validate checks the field values on CgroupMemoryConfig with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*CgroupMemoryConfig) ValidateAll

func (m *CgroupMemoryConfig) ValidateAll() error

ValidateAll checks the field values on CgroupMemoryConfig with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in CgroupMemoryConfigMultiError, or nil if none found.

type CgroupMemoryConfigMultiError

type CgroupMemoryConfigMultiError []error

CgroupMemoryConfigMultiError is an error wrapping multiple validation errors returned by CgroupMemoryConfig.ValidateAll() if the designated constraints aren't met.

func (CgroupMemoryConfigMultiError) AllErrors

func (m CgroupMemoryConfigMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (CgroupMemoryConfigMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type CgroupMemoryConfigValidationError

type CgroupMemoryConfigValidationError struct {
	// contains filtered or unexported fields
}

CgroupMemoryConfigValidationError is the validation error returned by CgroupMemoryConfig.Validate if the designated constraints aren't met.

func (CgroupMemoryConfigValidationError) Cause

Cause function returns cause value.

func (CgroupMemoryConfigValidationError) Error

Error satisfies the builtin error interface

func (CgroupMemoryConfigValidationError) ErrorName

ErrorName returns error name.

func (CgroupMemoryConfigValidationError) Field

Field function returns field value.

func (CgroupMemoryConfigValidationError) Key

Key function returns key value.

func (CgroupMemoryConfigValidationError) Reason

Reason function returns reason value.

Source Files

cgroup_memory.pb.go cgroup_memory.pb.validate.go

Version
v1.37.0 (latest)
Published
Jan 13, 2026
Platform
linux/amd64
Imports
18 packages
Last checked
1 hour ago

Tools for package owners.