package open_telemetryv3

import "github.com/envoyproxy/go-control-plane/envoy/extensions/stat_sinks/open_telemetry/v3"

Index

Variables

var File_envoy_extensions_stat_sinks_open_telemetry_v3_open_telemetry_proto protoreflect.FileDescriptor

Types

type SinkConfig

type SinkConfig struct {

	// Types that are valid to be assigned to ProtocolSpecifier:
	//
	//	*SinkConfig_GrpcService
	ProtocolSpecifier isSinkConfig_ProtocolSpecifier `protobuf_oneof:"protocol_specifier"`
	// Attributes to be associated with the resource in the OTLP message.
	// [#extension-category: envoy.tracers.opentelemetry.resource_detectors]
	ResourceDetectors []*v3.TypedExtensionConfig `protobuf:"bytes,7,rep,name=resource_detectors,json=resourceDetectors,proto3" json:"resource_detectors,omitempty"`
	// If set to true, counters will be emitted as deltas, and the OTLP message will have
	// “AGGREGATION_TEMPORALITY_DELTA“ set as AggregationTemporality.
	ReportCountersAsDeltas bool `protobuf:"varint,2,opt,name=report_counters_as_deltas,json=reportCountersAsDeltas,proto3" json:"report_counters_as_deltas,omitempty"`
	// If set to true, histograms will be emitted as deltas, and the OTLP message will have
	// “AGGREGATION_TEMPORALITY_DELTA“ set as AggregationTemporality.
	ReportHistogramsAsDeltas bool `protobuf:"varint,3,opt,name=report_histograms_as_deltas,json=reportHistogramsAsDeltas,proto3" json:"report_histograms_as_deltas,omitempty"`
	// If set to true, metrics will have their tags emitted as OTLP attributes, which may
	// contain values used by the tag extractor or additional tags added during stats creation.
	// Otherwise, no attributes will be associated with the export message. Default value is true.
	EmitTagsAsAttributes *wrapperspb.BoolValue `protobuf:"bytes,4,opt,name=emit_tags_as_attributes,json=emitTagsAsAttributes,proto3" json:"emit_tags_as_attributes,omitempty"`
	// If set to true, metric names will be represented as the tag extracted name instead
	// of the full metric name. Default value is true.
	UseTagExtractedName *wrapperspb.BoolValue `protobuf:"bytes,5,opt,name=use_tag_extracted_name,json=useTagExtractedName,proto3" json:"use_tag_extracted_name,omitempty"`
	// If set, emitted stats names will be prepended with a prefix, so full stat name will be
	// <prefix>.<stats_name>. For example, if the stat name is "foo.bar" and prefix is
	// "pre", the full stat name will be "pre.foo.bar". If this field is not set, there is no
	// prefix added. According to the example, the full stat name will remain "foo.bar".
	Prefix string `protobuf:"bytes,6,opt,name=prefix,proto3" json:"prefix,omitempty"`
	// The custom conversion from a stat to a metric. Currently, the only supported input is
	// “envoy.extensions.matching.common_inputs.stats.v3.StatFullNameMatchInput“.
	// The supported actions are
	// - “envoy.extensions.stat_sinks.open_telemetry.v3.SinkConfig.DropAction“.
	// - “envoy.extensions.stat_sinks.open_telemetry.v3.SinkConfig.ConversionAction“.
	// If stats are not matched, they will be directly converted to OTLP metrics as usual.
	CustomMetricConversions *v31.Matcher `protobuf:"bytes,8,opt,name=custom_metric_conversions,json=customMetricConversions,proto3" json:"custom_metric_conversions,omitempty"`
	// contains filtered or unexported fields
}

[#next-free-field: 9]

func (*SinkConfig) Descriptor

func (*SinkConfig) Descriptor() ([]byte, []int)

Deprecated: Use SinkConfig.ProtoReflect.Descriptor instead.

func (*SinkConfig) GetCustomMetricConversions

func (x *SinkConfig) GetCustomMetricConversions() *v31.Matcher

func (*SinkConfig) GetEmitTagsAsAttributes

func (x *SinkConfig) GetEmitTagsAsAttributes() *wrapperspb.BoolValue

func (*SinkConfig) GetGrpcService

func (x *SinkConfig) GetGrpcService() *v3.GrpcService

func (*SinkConfig) GetPrefix

func (x *SinkConfig) GetPrefix() string

func (*SinkConfig) GetProtocolSpecifier

func (x *SinkConfig) GetProtocolSpecifier() isSinkConfig_ProtocolSpecifier

func (*SinkConfig) GetReportCountersAsDeltas

func (x *SinkConfig) GetReportCountersAsDeltas() bool

func (*SinkConfig) GetReportHistogramsAsDeltas

func (x *SinkConfig) GetReportHistogramsAsDeltas() bool

func (*SinkConfig) GetResourceDetectors

func (x *SinkConfig) GetResourceDetectors() []*v3.TypedExtensionConfig

func (*SinkConfig) GetUseTagExtractedName

func (x *SinkConfig) GetUseTagExtractedName() *wrapperspb.BoolValue

func (*SinkConfig) ProtoMessage

func (*SinkConfig) ProtoMessage()

func (*SinkConfig) ProtoReflect

func (x *SinkConfig) ProtoReflect() protoreflect.Message

func (*SinkConfig) Reset

func (x *SinkConfig) Reset()

func (*SinkConfig) String

func (x *SinkConfig) String() string

func (*SinkConfig) Validate

func (m *SinkConfig) Validate() error

Validate checks the field values on SinkConfig with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*SinkConfig) ValidateAll

func (m *SinkConfig) ValidateAll() error

ValidateAll checks the field values on SinkConfig with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in SinkConfigMultiError, or nil if none found.

type SinkConfigMultiError

type SinkConfigMultiError []error

SinkConfigMultiError is an error wrapping multiple validation errors returned by SinkConfig.ValidateAll() if the designated constraints aren't met.

func (SinkConfigMultiError) AllErrors

func (m SinkConfigMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (SinkConfigMultiError) Error

func (m SinkConfigMultiError) Error() string

Error returns a concatenation of all the error messages it wraps.

type SinkConfigValidationError

type SinkConfigValidationError struct {
	// contains filtered or unexported fields
}

SinkConfigValidationError is the validation error returned by SinkConfig.Validate if the designated constraints aren't met.

func (SinkConfigValidationError) Cause

func (e SinkConfigValidationError) Cause() error

Cause function returns cause value.

func (SinkConfigValidationError) Error

Error satisfies the builtin error interface

func (SinkConfigValidationError) ErrorName

func (e SinkConfigValidationError) ErrorName() string

ErrorName returns error name.

func (SinkConfigValidationError) Field

Field function returns field value.

func (SinkConfigValidationError) Key

Key function returns key value.

func (SinkConfigValidationError) Reason

func (e SinkConfigValidationError) Reason() string

Reason function returns reason value.

type SinkConfig_ConversionAction

type SinkConfig_ConversionAction struct {

	// The metric name to use for the stat.
	MetricName string `protobuf:"bytes,2,opt,name=metric_name,json=metricName,proto3" json:"metric_name,omitempty"`
	// Static metric labels to use for the metric.
	StaticMetricLabels []*v1.KeyValue `protobuf:"bytes,3,rep,name=static_metric_labels,json=staticMetricLabels,proto3" json:"static_metric_labels,omitempty"`
	// contains filtered or unexported fields
}

ConversionAction is used to convert a stat to a metric. If a stat matches, the metric_name and static_metric_labels will be used to create the metric. This can be used to rename a stat, add static labels, and aggregate multiple stats into a single metric.

func (*SinkConfig_ConversionAction) Descriptor

func (*SinkConfig_ConversionAction) Descriptor() ([]byte, []int)

Deprecated: Use SinkConfig_ConversionAction.ProtoReflect.Descriptor instead.

func (*SinkConfig_ConversionAction) GetMetricName

func (x *SinkConfig_ConversionAction) GetMetricName() string

func (*SinkConfig_ConversionAction) GetStaticMetricLabels

func (x *SinkConfig_ConversionAction) GetStaticMetricLabels() []*v1.KeyValue

func (*SinkConfig_ConversionAction) ProtoMessage

func (*SinkConfig_ConversionAction) ProtoMessage()

func (*SinkConfig_ConversionAction) ProtoReflect

func (*SinkConfig_ConversionAction) Reset

func (x *SinkConfig_ConversionAction) Reset()

func (*SinkConfig_ConversionAction) String

func (x *SinkConfig_ConversionAction) String() string

func (*SinkConfig_ConversionAction) Validate

func (m *SinkConfig_ConversionAction) Validate() error

Validate checks the field values on SinkConfig_ConversionAction with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*SinkConfig_ConversionAction) ValidateAll

func (m *SinkConfig_ConversionAction) ValidateAll() error

ValidateAll checks the field values on SinkConfig_ConversionAction with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in SinkConfig_ConversionActionMultiError, or nil if none found.

type SinkConfig_ConversionActionMultiError

type SinkConfig_ConversionActionMultiError []error

SinkConfig_ConversionActionMultiError is an error wrapping multiple validation errors returned by SinkConfig_ConversionAction.ValidateAll() if the designated constraints aren't met.

func (SinkConfig_ConversionActionMultiError) AllErrors

AllErrors returns a list of validation violation errors.

func (SinkConfig_ConversionActionMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type SinkConfig_ConversionActionValidationError

type SinkConfig_ConversionActionValidationError struct {
	// contains filtered or unexported fields
}

SinkConfig_ConversionActionValidationError is the validation error returned by SinkConfig_ConversionAction.Validate if the designated constraints aren't met.

func (SinkConfig_ConversionActionValidationError) Cause

Cause function returns cause value.

func (SinkConfig_ConversionActionValidationError) Error

Error satisfies the builtin error interface

func (SinkConfig_ConversionActionValidationError) ErrorName

ErrorName returns error name.

func (SinkConfig_ConversionActionValidationError) Field

Field function returns field value.

func (SinkConfig_ConversionActionValidationError) Key

Key function returns key value.

func (SinkConfig_ConversionActionValidationError) Reason

Reason function returns reason value.

type SinkConfig_DropAction

type SinkConfig_DropAction struct {
	// contains filtered or unexported fields
}

DropAction is an action that, when matched, will prevent the stat from being converted to an OTLP metric and flushed.

func (*SinkConfig_DropAction) Descriptor

func (*SinkConfig_DropAction) Descriptor() ([]byte, []int)

Deprecated: Use SinkConfig_DropAction.ProtoReflect.Descriptor instead.

func (*SinkConfig_DropAction) ProtoMessage

func (*SinkConfig_DropAction) ProtoMessage()

func (*SinkConfig_DropAction) ProtoReflect

func (x *SinkConfig_DropAction) ProtoReflect() protoreflect.Message

func (*SinkConfig_DropAction) Reset

func (x *SinkConfig_DropAction) Reset()

func (*SinkConfig_DropAction) String

func (x *SinkConfig_DropAction) String() string

func (*SinkConfig_DropAction) Validate

func (m *SinkConfig_DropAction) Validate() error

Validate checks the field values on SinkConfig_DropAction with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*SinkConfig_DropAction) ValidateAll

func (m *SinkConfig_DropAction) ValidateAll() error

ValidateAll checks the field values on SinkConfig_DropAction with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in SinkConfig_DropActionMultiError, or nil if none found.

type SinkConfig_DropActionMultiError

type SinkConfig_DropActionMultiError []error

SinkConfig_DropActionMultiError is an error wrapping multiple validation errors returned by SinkConfig_DropAction.ValidateAll() if the designated constraints aren't met.

func (SinkConfig_DropActionMultiError) AllErrors

func (m SinkConfig_DropActionMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (SinkConfig_DropActionMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type SinkConfig_DropActionValidationError

type SinkConfig_DropActionValidationError struct {
	// contains filtered or unexported fields
}

SinkConfig_DropActionValidationError is the validation error returned by SinkConfig_DropAction.Validate if the designated constraints aren't met.

func (SinkConfig_DropActionValidationError) Cause

Cause function returns cause value.

func (SinkConfig_DropActionValidationError) Error

Error satisfies the builtin error interface

func (SinkConfig_DropActionValidationError) ErrorName

ErrorName returns error name.

func (SinkConfig_DropActionValidationError) Field

Field function returns field value.

func (SinkConfig_DropActionValidationError) Key

Key function returns key value.

func (SinkConfig_DropActionValidationError) Reason

Reason function returns reason value.

type SinkConfig_GrpcService

type SinkConfig_GrpcService struct {
	// The upstream gRPC cluster that implements the OTLP/gRPC collector.
	GrpcService *v3.GrpcService `protobuf:"bytes,1,opt,name=grpc_service,json=grpcService,proto3,oneof"`
}

Source Files

open_telemetry.pb.go open_telemetry.pb.validate.go

Version
v1.37.0 (latest)
Published
Jan 13, 2026
Platform
linux/amd64
Imports
23 packages
Last checked
1 hour ago

Tools for package owners.