package config

import "github.com/envoyproxy/go-control-plane/pkg/server/config"

Index

Types

type Opts

type Opts struct {
	// If true respond to ADS requests with a guaranteed resource ordering
	Ordered bool

	Logger log.Logger
	// contains filtered or unexported fields
}

Opts for individual xDS implementations that can be utilized through the functional opts pattern.

func NewOpts

func NewOpts() Opts

func (Opts) IsLegacyWildcardActive

func (o Opts) IsLegacyWildcardActive(typeURL string) bool

IsLegacyWildcardActive returns whether legacy wildcard mode is active for the given resource type. Returns true if legacy wildcard mode is active, false if it has been deactivated.

type XDSOption

type XDSOption func(*Opts)

Each xDS implementation should implement their own functional opts. It is recommended that config values be added in this package specifically, but the individual opts functions should be in their respective implementation package so the import looks like the following:

`sotw.WithOrderedADS()` `delta.WithOrderedADS()`

this allows for easy inference as to which opt applies to what implementation.

func DeactivateLegacyWildcard

func DeactivateLegacyWildcard() XDSOption

func DeactivateLegacyWildcardForTypes

func DeactivateLegacyWildcardForTypes(types []string) XDSOption

Source Files

config.go doc.go

Version
v0.14.0 (latest)
Published
Nov 4, 2025
Platform
linux/amd64
Imports
1 packages
Last checked
4 months ago

Tools for package owners.