package delta
import "github.com/envoyproxy/go-control-plane/pkg/server/delta/v3"
Index ¶
- func DeactivateLegacyWildcard() config.XDSOption
- func DeactivateLegacyWildcardForTypes(types []string) config.XDSOption
- func WithLogger(logger log.Logger) config.XDSOption
- type Callbacks
- type Server
Functions ¶
func DeactivateLegacyWildcard ¶
DeactivateLegacyWildcard deactivates legacy wildcard mode for all resource types. In legacy wildcard mode, empty requests to a stream, are treated as wildcard requests as long as there is no request made with resources or explicit wildcard requests on the same stream. When deactivated, empty requests are treated as a request with no subscriptions to any resource. This is recommended for when you are using the go-control-plane to serve grpc-xds clients. These clients never want to treat an empty request as a wildcard subscription.
func DeactivateLegacyWildcardForTypes ¶
DeactivateLegacyWildcardForTypes deactivates legacy wildcard mode for specific resource types. In legacy wildcard mode, empty requests to a stream, are treated as wildcard requests as long as there is no request made with resources or explicit wildcard requests on the same stream. When deactivated, empty requests are treated as a request with no subscriptions to any resource.
func WithLogger ¶
WithLogger configures the server logger. Defaults to no logging
Types ¶
type Callbacks ¶
type Callbacks interface {
// OnDeltaStreamOpen is called once an incremental xDS stream is open with a stream ID and the type URL (or "" for ADS).
// Returning an error will end processing and close the stream. OnStreamClosed will still be called.
OnDeltaStreamOpen(context.Context, int64, string) error
// OnDeltaStreamClosed is called immediately prior to closing an xDS stream with a stream ID.
OnDeltaStreamClosed(int64, *core.Node)
// OnStreamDeltaRequest is called once a request is received on a stream.
// Returning an error will end processing and close the stream. OnStreamClosed will still be called.
OnStreamDeltaRequest(int64, *discovery.DeltaDiscoveryRequest) error
// OnStreamDeltaResponse is called immediately prior to sending a response on a stream.
OnStreamDeltaResponse(int64, *discovery.DeltaDiscoveryRequest, *discovery.DeltaDiscoveryResponse)
}
type Server ¶
Server is a wrapper interface which is meant to hold the proper stream handler for each xDS protocol.
func NewServer ¶
func NewServer(ctx context.Context, config cache.ConfigWatcher, callbacks Callbacks, opts ...config.XDSOption) Server
NewServer creates a delta xDS specific server which utilizes a ConfigWatcher and delta Callbacks.
Source Files ¶
- Version
- v0.14.0 (latest)
- Published
- Nov 4, 2025
- Platform
- linux/amd64
- Imports
- 14 packages
- Last checked
- 4 months ago –
Tools for package owners.