package statsv3
import "github.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/stats/v3"
Index ¶
- Variables
- type Config
- func (*Config) Descriptor() ([]byte, []int)
- func (x *Config) GetCounters() []*Config_Counter
- func (x *Config) GetHistograms() []*Config_Histogram
- func (x *Config) GetStatPrefix() string
- func (*Config) ProtoMessage()
- func (x *Config) ProtoReflect() protoreflect.Message
- func (x *Config) Reset()
- func (x *Config) String() string
- func (m *Config) Validate() error
- func (m *Config) ValidateAll() error
- type ConfigMultiError
- type ConfigValidationError
- func (e ConfigValidationError) Cause() error
- func (e ConfigValidationError) Error() string
- func (e ConfigValidationError) ErrorName() string
- func (e ConfigValidationError) Field() string
- func (e ConfigValidationError) Key() bool
- func (e ConfigValidationError) Reason() string
- type Config_Counter
- func (*Config_Counter) Descriptor() ([]byte, []int)
- func (x *Config_Counter) GetStat() *Config_Stat
- func (x *Config_Counter) GetValueFixed() *wrapperspb.UInt64Value
- func (x *Config_Counter) GetValueFormat() string
- func (*Config_Counter) ProtoMessage()
- func (x *Config_Counter) ProtoReflect() protoreflect.Message
- func (x *Config_Counter) Reset()
- func (x *Config_Counter) String() string
- func (m *Config_Counter) Validate() error
- func (m *Config_Counter) ValidateAll() error
- type Config_CounterMultiError
- func (m Config_CounterMultiError) AllErrors() []error
- func (m Config_CounterMultiError) Error() string
- type Config_CounterValidationError
- func (e Config_CounterValidationError) Cause() error
- func (e Config_CounterValidationError) Error() string
- func (e Config_CounterValidationError) ErrorName() string
- func (e Config_CounterValidationError) Field() string
- func (e Config_CounterValidationError) Key() bool
- func (e Config_CounterValidationError) Reason() string
- type Config_Histogram
- func (*Config_Histogram) Descriptor() ([]byte, []int)
- func (x *Config_Histogram) GetStat() *Config_Stat
- func (x *Config_Histogram) GetUnit() Config_Histogram_Unit
- func (x *Config_Histogram) GetValueFormat() string
- func (*Config_Histogram) ProtoMessage()
- func (x *Config_Histogram) ProtoReflect() protoreflect.Message
- func (x *Config_Histogram) Reset()
- func (x *Config_Histogram) String() string
- func (m *Config_Histogram) Validate() error
- func (m *Config_Histogram) ValidateAll() error
- type Config_HistogramMultiError
- func (m Config_HistogramMultiError) AllErrors() []error
- func (m Config_HistogramMultiError) Error() string
- type Config_HistogramValidationError
- func (e Config_HistogramValidationError) Cause() error
- func (e Config_HistogramValidationError) Error() string
- func (e Config_HistogramValidationError) ErrorName() string
- func (e Config_HistogramValidationError) Field() string
- func (e Config_HistogramValidationError) Key() bool
- func (e Config_HistogramValidationError) Reason() string
- type Config_Histogram_Unit
- func (Config_Histogram_Unit) Descriptor() protoreflect.EnumDescriptor
- func (x Config_Histogram_Unit) Enum() *Config_Histogram_Unit
- func (Config_Histogram_Unit) EnumDescriptor() ([]byte, []int)
- func (x Config_Histogram_Unit) Number() protoreflect.EnumNumber
- func (x Config_Histogram_Unit) String() string
- func (Config_Histogram_Unit) Type() protoreflect.EnumType
- type Config_Stat
- func (*Config_Stat) Descriptor() ([]byte, []int)
- func (x *Config_Stat) GetName() string
- func (x *Config_Stat) GetTags() []*Config_Tag
- func (*Config_Stat) ProtoMessage()
- func (x *Config_Stat) ProtoReflect() protoreflect.Message
- func (x *Config_Stat) Reset()
- func (x *Config_Stat) String() string
- func (m *Config_Stat) Validate() error
- func (m *Config_Stat) ValidateAll() error
- type Config_StatMultiError
- type Config_StatValidationError
- func (e Config_StatValidationError) Cause() error
- func (e Config_StatValidationError) Error() string
- func (e Config_StatValidationError) ErrorName() string
- func (e Config_StatValidationError) Field() string
- func (e Config_StatValidationError) Key() bool
- func (e Config_StatValidationError) Reason() string
- type Config_Tag
- func (*Config_Tag) Descriptor() ([]byte, []int)
- func (x *Config_Tag) GetName() string
- func (x *Config_Tag) GetValueFormat() string
- func (*Config_Tag) ProtoMessage()
- func (x *Config_Tag) ProtoReflect() protoreflect.Message
- func (x *Config_Tag) Reset()
- func (x *Config_Tag) String() string
- func (m *Config_Tag) Validate() error
- func (m *Config_Tag) ValidateAll() error
- type Config_TagMultiError
- type Config_TagValidationError
Variables ¶
var ( Config_Histogram_Unit_name = map[int32]string{ 0: "Unspecified", 1: "Bytes", 2: "Microseconds", 3: "Milliseconds", 4: "Percent", } Config_Histogram_Unit_value = map[string]int32{ "Unspecified": 0, "Bytes": 1, "Microseconds": 2, "Milliseconds": 3, "Percent": 4, } )
Enum value maps for Config_Histogram_Unit.
var File_envoy_extensions_access_loggers_stats_v3_stats_proto protoreflect.FileDescriptor
Types ¶
type Config ¶
type Config struct {
// The stat prefix for the generated stats.
StatPrefix string `protobuf:"bytes,1,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
// The histograms this logger will emit.
Histograms []*Config_Histogram `protobuf:"bytes,3,rep,name=histograms,proto3" json:"histograms,omitempty"`
// The counters this logger will emit.
Counters []*Config_Counter `protobuf:"bytes,4,rep,name=counters,proto3" json:"counters,omitempty"`
// contains filtered or unexported fields
}
func (*Config) Descriptor ¶
Deprecated: Use Config.ProtoReflect.Descriptor instead.
func (*Config) GetCounters ¶
func (x *Config) GetCounters() []*Config_Counter
func (*Config) GetHistograms ¶
func (x *Config) GetHistograms() []*Config_Histogram
func (*Config) GetStatPrefix ¶
func (*Config) ProtoMessage ¶
func (*Config) ProtoMessage()
func (*Config) ProtoReflect ¶
func (x *Config) ProtoReflect() protoreflect.Message
func (*Config) Reset ¶
func (x *Config) Reset()
func (*Config) String ¶
func (*Config) Validate ¶
Validate checks the field values on Config with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*Config) ValidateAll ¶
ValidateAll checks the field values on Config with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in ConfigMultiError, or nil if none found.
type ConfigMultiError ¶
type ConfigMultiError []error
ConfigMultiError is an error wrapping multiple validation errors returned by Config.ValidateAll() if the designated constraints aren't met.
func (ConfigMultiError) AllErrors ¶
func (m ConfigMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (ConfigMultiError) Error ¶
func (m ConfigMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type ConfigValidationError ¶
type ConfigValidationError struct {
// contains filtered or unexported fields
}
ConfigValidationError is the validation error returned by Config.Validate if the designated constraints aren't met.
func (ConfigValidationError) Cause ¶
func (e ConfigValidationError) Cause() error
Cause function returns cause value.
func (ConfigValidationError) Error ¶
func (e ConfigValidationError) Error() string
Error satisfies the builtin error interface
func (ConfigValidationError) ErrorName ¶
func (e ConfigValidationError) ErrorName() string
ErrorName returns error name.
func (ConfigValidationError) Field ¶
func (e ConfigValidationError) Field() string
Field function returns field value.
func (ConfigValidationError) Key ¶
func (e ConfigValidationError) Key() bool
Key function returns key value.
func (ConfigValidationError) Reason ¶
func (e ConfigValidationError) Reason() string
Reason function returns reason value.
type Config_Counter ¶
type Config_Counter struct {
// The name and tags of this counter.
Stat *Config_Stat `protobuf:"bytes,1,opt,name=stat,proto3" json:"stat,omitempty"`
// The format string for the value to add to this counter, using :ref:`command operators <config_access_log_command_operators>`.
// One of “value_format“ or “value_fixed“ must be configured.
ValueFormat string `protobuf:"bytes,2,opt,name=value_format,json=valueFormat,proto3" json:"value_format,omitempty"`
// A fixed value to add to this counter.
// One of “value_format“ or “value_fixed“ must be configured.
ValueFixed *wrapperspb.UInt64Value `protobuf:"bytes,3,opt,name=value_fixed,json=valueFixed,proto3" json:"value_fixed,omitempty"`
// contains filtered or unexported fields
}
Configuration for a counter stat.
func (*Config_Counter) Descriptor ¶
func (*Config_Counter) Descriptor() ([]byte, []int)
Deprecated: Use Config_Counter.ProtoReflect.Descriptor instead.
func (*Config_Counter) GetStat ¶
func (x *Config_Counter) GetStat() *Config_Stat
func (*Config_Counter) GetValueFixed ¶
func (x *Config_Counter) GetValueFixed() *wrapperspb.UInt64Value
func (*Config_Counter) GetValueFormat ¶
func (x *Config_Counter) GetValueFormat() string
func (*Config_Counter) ProtoMessage ¶
func (*Config_Counter) ProtoMessage()
func (*Config_Counter) ProtoReflect ¶
func (x *Config_Counter) ProtoReflect() protoreflect.Message
func (*Config_Counter) Reset ¶
func (x *Config_Counter) Reset()
func (*Config_Counter) String ¶
func (x *Config_Counter) String() string
func (*Config_Counter) Validate ¶
func (m *Config_Counter) Validate() error
Validate checks the field values on Config_Counter with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*Config_Counter) ValidateAll ¶
func (m *Config_Counter) ValidateAll() error
ValidateAll checks the field values on Config_Counter with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in Config_CounterMultiError, or nil if none found.
type Config_CounterMultiError ¶
type Config_CounterMultiError []error
Config_CounterMultiError is an error wrapping multiple validation errors returned by Config_Counter.ValidateAll() if the designated constraints aren't met.
func (Config_CounterMultiError) AllErrors ¶
func (m Config_CounterMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (Config_CounterMultiError) Error ¶
func (m Config_CounterMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type Config_CounterValidationError ¶
type Config_CounterValidationError struct {
// contains filtered or unexported fields
}
Config_CounterValidationError is the validation error returned by Config_Counter.Validate if the designated constraints aren't met.
func (Config_CounterValidationError) Cause ¶
func (e Config_CounterValidationError) Cause() error
Cause function returns cause value.
func (Config_CounterValidationError) Error ¶
func (e Config_CounterValidationError) Error() string
Error satisfies the builtin error interface
func (Config_CounterValidationError) ErrorName ¶
func (e Config_CounterValidationError) ErrorName() string
ErrorName returns error name.
func (Config_CounterValidationError) Field ¶
func (e Config_CounterValidationError) Field() string
Field function returns field value.
func (Config_CounterValidationError) Key ¶
func (e Config_CounterValidationError) Key() bool
Key function returns key value.
func (Config_CounterValidationError) Reason ¶
func (e Config_CounterValidationError) Reason() string
Reason function returns reason value.
type Config_Histogram ¶
type Config_Histogram struct {
// The name and tags of this histogram.
Stat *Config_Stat `protobuf:"bytes,1,opt,name=stat,proto3" json:"stat,omitempty"`
// The units for this histogram.
Unit Config_Histogram_Unit `protobuf:"varint,2,opt,name=unit,proto3,enum=envoy.extensions.access_loggers.stats.v3.Config_Histogram_Unit" json:"unit,omitempty"`
// The format string for the value of this histogram, using :ref:`command operators <config_access_log_command_operators>`.
// This must evaluate to a positive number.
ValueFormat string `protobuf:"bytes,3,opt,name=value_format,json=valueFormat,proto3" json:"value_format,omitempty"`
// contains filtered or unexported fields
}
Configuration for a histogram stat.
func (*Config_Histogram) Descriptor ¶
func (*Config_Histogram) Descriptor() ([]byte, []int)
Deprecated: Use Config_Histogram.ProtoReflect.Descriptor instead.
func (*Config_Histogram) GetStat ¶
func (x *Config_Histogram) GetStat() *Config_Stat
func (*Config_Histogram) GetUnit ¶
func (x *Config_Histogram) GetUnit() Config_Histogram_Unit
func (*Config_Histogram) GetValueFormat ¶
func (x *Config_Histogram) GetValueFormat() string
func (*Config_Histogram) ProtoMessage ¶
func (*Config_Histogram) ProtoMessage()
func (*Config_Histogram) ProtoReflect ¶
func (x *Config_Histogram) ProtoReflect() protoreflect.Message
func (*Config_Histogram) Reset ¶
func (x *Config_Histogram) Reset()
func (*Config_Histogram) String ¶
func (x *Config_Histogram) String() string
func (*Config_Histogram) Validate ¶
func (m *Config_Histogram) Validate() error
Validate checks the field values on Config_Histogram with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*Config_Histogram) ValidateAll ¶
func (m *Config_Histogram) ValidateAll() error
ValidateAll checks the field values on Config_Histogram with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in Config_HistogramMultiError, or nil if none found.
type Config_HistogramMultiError ¶
type Config_HistogramMultiError []error
Config_HistogramMultiError is an error wrapping multiple validation errors returned by Config_Histogram.ValidateAll() if the designated constraints aren't met.
func (Config_HistogramMultiError) AllErrors ¶
func (m Config_HistogramMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (Config_HistogramMultiError) Error ¶
func (m Config_HistogramMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type Config_HistogramValidationError ¶
type Config_HistogramValidationError struct {
// contains filtered or unexported fields
}
Config_HistogramValidationError is the validation error returned by Config_Histogram.Validate if the designated constraints aren't met.
func (Config_HistogramValidationError) Cause ¶
func (e Config_HistogramValidationError) Cause() error
Cause function returns cause value.
func (Config_HistogramValidationError) Error ¶
func (e Config_HistogramValidationError) Error() string
Error satisfies the builtin error interface
func (Config_HistogramValidationError) ErrorName ¶
func (e Config_HistogramValidationError) ErrorName() string
ErrorName returns error name.
func (Config_HistogramValidationError) Field ¶
func (e Config_HistogramValidationError) Field() string
Field function returns field value.
func (Config_HistogramValidationError) Key ¶
func (e Config_HistogramValidationError) Key() bool
Key function returns key value.
func (Config_HistogramValidationError) Reason ¶
func (e Config_HistogramValidationError) Reason() string
Reason function returns reason value.
type Config_Histogram_Unit ¶
type Config_Histogram_Unit int32
The histogram units. The units are needed for some stat sinks.
const ( Config_Histogram_Unspecified Config_Histogram_Unit = 0 Config_Histogram_Bytes Config_Histogram_Unit = 1 Config_Histogram_Microseconds Config_Histogram_Unit = 2 Config_Histogram_Milliseconds Config_Histogram_Unit = 3 // Values are scaled to range 0-1.0, indicating 0%-100%. Values can be outside this range, // but must be positive. Values extremely far out of this range may overflow. Config_Histogram_Percent Config_Histogram_Unit = 4 )
func (Config_Histogram_Unit) Descriptor ¶
func (Config_Histogram_Unit) Descriptor() protoreflect.EnumDescriptor
func (Config_Histogram_Unit) Enum ¶
func (x Config_Histogram_Unit) Enum() *Config_Histogram_Unit
func (Config_Histogram_Unit) EnumDescriptor ¶
func (Config_Histogram_Unit) EnumDescriptor() ([]byte, []int)
Deprecated: Use Config_Histogram_Unit.Descriptor instead.
func (Config_Histogram_Unit) Number ¶
func (x Config_Histogram_Unit) Number() protoreflect.EnumNumber
func (Config_Histogram_Unit) String ¶
func (x Config_Histogram_Unit) String() string
func (Config_Histogram_Unit) Type ¶
func (Config_Histogram_Unit) Type() protoreflect.EnumType
type Config_Stat ¶
type Config_Stat struct {
// The name of the stat.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The tags for the stat.
Tags []*Config_Tag `protobuf:"bytes,2,rep,name=tags,proto3" json:"tags,omitempty"`
// contains filtered or unexported fields
}
Defines the name and tags of a stat.
func (*Config_Stat) Descriptor ¶
func (*Config_Stat) Descriptor() ([]byte, []int)
Deprecated: Use Config_Stat.ProtoReflect.Descriptor instead.
func (*Config_Stat) GetName ¶
func (x *Config_Stat) GetName() string
func (*Config_Stat) GetTags ¶
func (x *Config_Stat) GetTags() []*Config_Tag
func (*Config_Stat) ProtoMessage ¶
func (*Config_Stat) ProtoMessage()
func (*Config_Stat) ProtoReflect ¶
func (x *Config_Stat) ProtoReflect() protoreflect.Message
func (*Config_Stat) Reset ¶
func (x *Config_Stat) Reset()
func (*Config_Stat) String ¶
func (x *Config_Stat) String() string
func (*Config_Stat) Validate ¶
func (m *Config_Stat) Validate() error
Validate checks the field values on Config_Stat with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*Config_Stat) ValidateAll ¶
func (m *Config_Stat) ValidateAll() error
ValidateAll checks the field values on Config_Stat with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in Config_StatMultiError, or nil if none found.
type Config_StatMultiError ¶
type Config_StatMultiError []error
Config_StatMultiError is an error wrapping multiple validation errors returned by Config_Stat.ValidateAll() if the designated constraints aren't met.
func (Config_StatMultiError) AllErrors ¶
func (m Config_StatMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (Config_StatMultiError) Error ¶
func (m Config_StatMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type Config_StatValidationError ¶
type Config_StatValidationError struct {
// contains filtered or unexported fields
}
Config_StatValidationError is the validation error returned by Config_Stat.Validate if the designated constraints aren't met.
func (Config_StatValidationError) Cause ¶
func (e Config_StatValidationError) Cause() error
Cause function returns cause value.
func (Config_StatValidationError) Error ¶
func (e Config_StatValidationError) Error() string
Error satisfies the builtin error interface
func (Config_StatValidationError) ErrorName ¶
func (e Config_StatValidationError) ErrorName() string
ErrorName returns error name.
func (Config_StatValidationError) Field ¶
func (e Config_StatValidationError) Field() string
Field function returns field value.
func (Config_StatValidationError) Key ¶
func (e Config_StatValidationError) Key() bool
Key function returns key value.
func (Config_StatValidationError) Reason ¶
func (e Config_StatValidationError) Reason() string
Reason function returns reason value.
type Config_Tag ¶
type Config_Tag struct {
// The name of the tag.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The value of the tag, using :ref:`command operators <config_access_log_command_operators>`.
ValueFormat string `protobuf:"bytes,2,opt,name=value_format,json=valueFormat,proto3" json:"value_format,omitempty"`
// contains filtered or unexported fields
}
Defines a tag on a stat.
func (*Config_Tag) Descriptor ¶
func (*Config_Tag) Descriptor() ([]byte, []int)
Deprecated: Use Config_Tag.ProtoReflect.Descriptor instead.
func (*Config_Tag) GetName ¶
func (x *Config_Tag) GetName() string
func (*Config_Tag) GetValueFormat ¶
func (x *Config_Tag) GetValueFormat() string
func (*Config_Tag) ProtoMessage ¶
func (*Config_Tag) ProtoMessage()
func (*Config_Tag) ProtoReflect ¶
func (x *Config_Tag) ProtoReflect() protoreflect.Message
func (*Config_Tag) Reset ¶
func (x *Config_Tag) Reset()
func (*Config_Tag) String ¶
func (x *Config_Tag) String() string
func (*Config_Tag) Validate ¶
func (m *Config_Tag) Validate() error
Validate checks the field values on Config_Tag with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*Config_Tag) ValidateAll ¶
func (m *Config_Tag) ValidateAll() error
ValidateAll checks the field values on Config_Tag with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in Config_TagMultiError, or nil if none found.
type Config_TagMultiError ¶
type Config_TagMultiError []error
Config_TagMultiError is an error wrapping multiple validation errors returned by Config_Tag.ValidateAll() if the designated constraints aren't met.
func (Config_TagMultiError) AllErrors ¶
func (m Config_TagMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (Config_TagMultiError) Error ¶
func (m Config_TagMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type Config_TagValidationError ¶
type Config_TagValidationError struct {
// contains filtered or unexported fields
}
Config_TagValidationError is the validation error returned by Config_Tag.Validate if the designated constraints aren't met.
func (Config_TagValidationError) Cause ¶
func (e Config_TagValidationError) Cause() error
Cause function returns cause value.
func (Config_TagValidationError) Error ¶
func (e Config_TagValidationError) Error() string
Error satisfies the builtin error interface
func (Config_TagValidationError) ErrorName ¶
func (e Config_TagValidationError) ErrorName() string
ErrorName returns error name.
func (Config_TagValidationError) Field ¶
func (e Config_TagValidationError) Field() string
Field function returns field value.
func (Config_TagValidationError) Key ¶
func (e Config_TagValidationError) Key() bool
Key function returns key value.
func (Config_TagValidationError) Reason ¶
func (e Config_TagValidationError) Reason() string
Reason function returns reason value.
Source Files ¶
stats.pb.go stats.pb.validate.go
- Version
- v1.37.0 (latest)
- Published
- Jan 13, 2026
- Platform
- linux/amd64
- Imports
- 21 packages
- Last checked
- 1 hour ago –
Tools for package owners.