package downstream_socket_interfacev3
import "github.com/envoyproxy/go-control-plane/envoy/extensions/bootstrap/reverse_tunnel/downstream_socket_interface/v3"
Index ¶
- Variables
- type DownstreamReverseConnectionSocketInterface
- func (*DownstreamReverseConnectionSocketInterface) Descriptor() ([]byte, []int)
- func (x *DownstreamReverseConnectionSocketInterface) GetEnableDetailedStats() bool
- func (x *DownstreamReverseConnectionSocketInterface) GetHttpHandshake() *DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig
- func (x *DownstreamReverseConnectionSocketInterface) GetStatPrefix() string
- func (*DownstreamReverseConnectionSocketInterface) ProtoMessage()
- func (x *DownstreamReverseConnectionSocketInterface) ProtoReflect() protoreflect.Message
- func (x *DownstreamReverseConnectionSocketInterface) Reset()
- func (x *DownstreamReverseConnectionSocketInterface) String() string
- func (m *DownstreamReverseConnectionSocketInterface) Validate() error
- func (m *DownstreamReverseConnectionSocketInterface) ValidateAll() error
- type DownstreamReverseConnectionSocketInterfaceMultiError
- func (m DownstreamReverseConnectionSocketInterfaceMultiError) AllErrors() []error
- func (m DownstreamReverseConnectionSocketInterfaceMultiError) Error() string
- type DownstreamReverseConnectionSocketInterfaceValidationError
- func (e DownstreamReverseConnectionSocketInterfaceValidationError) Cause() error
- func (e DownstreamReverseConnectionSocketInterfaceValidationError) Error() string
- func (e DownstreamReverseConnectionSocketInterfaceValidationError) ErrorName() string
- func (e DownstreamReverseConnectionSocketInterfaceValidationError) Field() string
- func (e DownstreamReverseConnectionSocketInterfaceValidationError) Key() bool
- func (e DownstreamReverseConnectionSocketInterfaceValidationError) Reason() string
- type DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig
- func (*DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) Descriptor() ([]byte, []int)
- func (x *DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) GetRequestPath() string
- func (*DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) ProtoMessage()
- func (x *DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) ProtoReflect() protoreflect.Message
- func (x *DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) Reset()
- func (x *DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) String() string
- func (m *DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) Validate() error
- func (m *DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) ValidateAll() error
- type DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigMultiError
- func (m DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigMultiError) AllErrors() []error
- func (m DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigMultiError) Error() string
- type DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError
- func (e DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError) Cause() error
- func (e DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError) Error() string
- func (e DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError) ErrorName() string
- func (e DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError) Field() string
- func (e DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError) Key() bool
- func (e DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError) Reason() string
Variables ¶
var File_envoy_extensions_bootstrap_reverse_tunnel_downstream_socket_interface_v3_downstream_reverse_connection_socket_interface_proto protoreflect.FileDescriptor
Types ¶
type DownstreamReverseConnectionSocketInterface ¶
type DownstreamReverseConnectionSocketInterface struct {
// Stat prefix to be used for downstream reverse connection socket interface stats.
StatPrefix string `protobuf:"bytes,1,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
// Enable detailed per-host and per-cluster statistics.
// When enabled, emits hidden statistics for individual hosts and clusters.
// Defaults to “false“.
EnableDetailedStats bool `protobuf:"varint,2,opt,name=enable_detailed_stats,json=enableDetailedStats,proto3" json:"enable_detailed_stats,omitempty"`
// Optional HTTP handshake configuration. When unset, the initiator envoy uses the defaults
// provided by “HttpHandshakeConfig“.
HttpHandshake *DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig `protobuf:"bytes,3,opt,name=http_handshake,json=httpHandshake,proto3" json:"http_handshake,omitempty"`
// contains filtered or unexported fields
}
Configuration for the downstream reverse connection socket interface. This interface initiates reverse connections to upstream Envoys and provides them as socket connections for downstream requests.
func (*DownstreamReverseConnectionSocketInterface) Descriptor ¶
func (*DownstreamReverseConnectionSocketInterface) Descriptor() ([]byte, []int)
Deprecated: Use DownstreamReverseConnectionSocketInterface.ProtoReflect.Descriptor instead.
func (*DownstreamReverseConnectionSocketInterface) GetEnableDetailedStats ¶
func (x *DownstreamReverseConnectionSocketInterface) GetEnableDetailedStats() bool
func (*DownstreamReverseConnectionSocketInterface) GetHttpHandshake ¶
func (x *DownstreamReverseConnectionSocketInterface) GetHttpHandshake() *DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig
func (*DownstreamReverseConnectionSocketInterface) GetStatPrefix ¶
func (x *DownstreamReverseConnectionSocketInterface) GetStatPrefix() string
func (*DownstreamReverseConnectionSocketInterface) ProtoMessage ¶
func (*DownstreamReverseConnectionSocketInterface) ProtoMessage()
func (*DownstreamReverseConnectionSocketInterface) ProtoReflect ¶
func (x *DownstreamReverseConnectionSocketInterface) ProtoReflect() protoreflect.Message
func (*DownstreamReverseConnectionSocketInterface) Reset ¶
func (x *DownstreamReverseConnectionSocketInterface) Reset()
func (*DownstreamReverseConnectionSocketInterface) String ¶
func (x *DownstreamReverseConnectionSocketInterface) String() string
func (*DownstreamReverseConnectionSocketInterface) Validate ¶
func (m *DownstreamReverseConnectionSocketInterface) Validate() error
Validate checks the field values on DownstreamReverseConnectionSocketInterface with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*DownstreamReverseConnectionSocketInterface) ValidateAll ¶
func (m *DownstreamReverseConnectionSocketInterface) ValidateAll() error
ValidateAll checks the field values on DownstreamReverseConnectionSocketInterface with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in DownstreamReverseConnectionSocketInterfaceMultiError, or nil if none found.
type DownstreamReverseConnectionSocketInterfaceMultiError ¶
type DownstreamReverseConnectionSocketInterfaceMultiError []error
DownstreamReverseConnectionSocketInterfaceMultiError is an error wrapping multiple validation errors returned by DownstreamReverseConnectionSocketInterface.ValidateAll() if the designated constraints aren't met.
func (DownstreamReverseConnectionSocketInterfaceMultiError) AllErrors ¶
func (m DownstreamReverseConnectionSocketInterfaceMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (DownstreamReverseConnectionSocketInterfaceMultiError) Error ¶
func (m DownstreamReverseConnectionSocketInterfaceMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type DownstreamReverseConnectionSocketInterfaceValidationError ¶
type DownstreamReverseConnectionSocketInterfaceValidationError struct {
// contains filtered or unexported fields
}
DownstreamReverseConnectionSocketInterfaceValidationError is the validation error returned by DownstreamReverseConnectionSocketInterface.Validate if the designated constraints aren't met.
func (DownstreamReverseConnectionSocketInterfaceValidationError) Cause ¶
func (e DownstreamReverseConnectionSocketInterfaceValidationError) Cause() error
Cause function returns cause value.
func (DownstreamReverseConnectionSocketInterfaceValidationError) Error ¶
func (e DownstreamReverseConnectionSocketInterfaceValidationError) Error() string
Error satisfies the builtin error interface
func (DownstreamReverseConnectionSocketInterfaceValidationError) ErrorName ¶
func (e DownstreamReverseConnectionSocketInterfaceValidationError) ErrorName() string
ErrorName returns error name.
func (DownstreamReverseConnectionSocketInterfaceValidationError) Field ¶
func (e DownstreamReverseConnectionSocketInterfaceValidationError) Field() string
Field function returns field value.
func (DownstreamReverseConnectionSocketInterfaceValidationError) Key ¶
func (e DownstreamReverseConnectionSocketInterfaceValidationError) Key() bool
Key function returns key value.
func (DownstreamReverseConnectionSocketInterfaceValidationError) Reason ¶
func (e DownstreamReverseConnectionSocketInterfaceValidationError) Reason() string
Reason function returns reason value.
type DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig ¶
type DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig struct {
// Request path used when issuing the HTTP reverse-connection handshake. Defaults to
// "/reverse_connections/request".
RequestPath string `protobuf:"bytes,1,opt,name=request_path,json=requestPath,proto3" json:"request_path,omitempty"`
// contains filtered or unexported fields
}
HTTP handshake settings for initiator envoy initiated reverse tunnels.
func (*DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) Descriptor ¶
func (*DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) Descriptor() ([]byte, []int)
Deprecated: Use DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig.ProtoReflect.Descriptor instead.
func (*DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) GetRequestPath ¶
func (x *DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) GetRequestPath() string
func (*DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) ProtoMessage ¶
func (*DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) ProtoMessage()
func (*DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) ProtoReflect ¶
func (x *DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) ProtoReflect() protoreflect.Message
func (*DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) Reset ¶
func (x *DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) Reset()
func (*DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) String ¶
func (x *DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) String() string
func (*DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) Validate ¶
func (m *DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) Validate() error
Validate checks the field values on DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) ValidateAll ¶
func (m *DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig) ValidateAll() error
ValidateAll checks the field values on DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigMultiError, or nil if none found.
type DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigMultiError ¶
type DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigMultiError []error
DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigMultiError is an error wrapping multiple validation errors returned by DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig.ValidateAll() if the designated constraints aren't met.
func (DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigMultiError) AllErrors ¶
func (m DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigMultiError) Error ¶
Error returns a concatenation of all the error messages it wraps.
type DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError ¶
type DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError struct {
// contains filtered or unexported fields
}
DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError is the validation error returned by DownstreamReverseConnectionSocketInterface_HttpHandshakeConfig.Validate if the designated constraints aren't met.
func (DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError) Cause ¶
func (e DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError) Cause() error
Cause function returns cause value.
func (DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError) Error ¶
func (e DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError) Error() string
Error satisfies the builtin error interface
func (DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError) ErrorName ¶
func (e DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError) ErrorName() string
ErrorName returns error name.
func (DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError) Field ¶
func (e DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError) Field() string
Field function returns field value.
func (DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError) Key ¶
Key function returns key value.
func (DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError) Reason ¶
func (e DownstreamReverseConnectionSocketInterface_HttpHandshakeConfigValidationError) Reason() string
Reason function returns reason value.
Source Files ¶
downstream_reverse_connection_socket_interface.pb.go downstream_reverse_connection_socket_interface.pb.validate.go
- Version
- v1.37.0 (latest)
- Published
- Jan 13, 2026
- Platform
- linux/amd64
- Imports
- 18 packages
- Last checked
- 6 hours ago –
Tools for package owners.