package google_iamv3
import "github.com/envoyproxy/go-control-plane/envoy/extensions/grpc_service/call_credentials/google_iam/v3"
Index ¶
- Variables
- type GoogleIamCredentials
- func (*GoogleIamCredentials) Descriptor() ([]byte, []int)
- func (x *GoogleIamCredentials) GetAuthoritySelector() string
- func (x *GoogleIamCredentials) GetAuthorizationToken() string
- func (*GoogleIamCredentials) ProtoMessage()
- func (x *GoogleIamCredentials) ProtoReflect() protoreflect.Message
- func (x *GoogleIamCredentials) Reset()
- func (x *GoogleIamCredentials) String() string
- func (m *GoogleIamCredentials) Validate() error
- func (m *GoogleIamCredentials) ValidateAll() error
- type GoogleIamCredentialsMultiError
- func (m GoogleIamCredentialsMultiError) AllErrors() []error
- func (m GoogleIamCredentialsMultiError) Error() string
- type GoogleIamCredentialsValidationError
- func (e GoogleIamCredentialsValidationError) Cause() error
- func (e GoogleIamCredentialsValidationError) Error() string
- func (e GoogleIamCredentialsValidationError) ErrorName() string
- func (e GoogleIamCredentialsValidationError) Field() string
- func (e GoogleIamCredentialsValidationError) Key() bool
- func (e GoogleIamCredentialsValidationError) Reason() string
Variables ¶
var File_envoy_extensions_grpc_service_call_credentials_google_iam_v3_google_iam_credentials_proto protoreflect.FileDescriptor
Types ¶
type GoogleIamCredentials ¶
type GoogleIamCredentials struct {
// Authorization token.
AuthorizationToken string `protobuf:"bytes,1,opt,name=authorization_token,json=authorizationToken,proto3" json:"authorization_token,omitempty"`
// Authority selector.
AuthoritySelector string `protobuf:"bytes,2,opt,name=authority_selector,json=authoritySelector,proto3" json:"authority_selector,omitempty"`
// contains filtered or unexported fields
}
[#not-implemented-hide:]
func (*GoogleIamCredentials) Descriptor ¶
func (*GoogleIamCredentials) Descriptor() ([]byte, []int)
Deprecated: Use GoogleIamCredentials.ProtoReflect.Descriptor instead.
func (*GoogleIamCredentials) GetAuthoritySelector ¶
func (x *GoogleIamCredentials) GetAuthoritySelector() string
func (*GoogleIamCredentials) GetAuthorizationToken ¶
func (x *GoogleIamCredentials) GetAuthorizationToken() string
func (*GoogleIamCredentials) ProtoMessage ¶
func (*GoogleIamCredentials) ProtoMessage()
func (*GoogleIamCredentials) ProtoReflect ¶
func (x *GoogleIamCredentials) ProtoReflect() protoreflect.Message
func (*GoogleIamCredentials) Reset ¶
func (x *GoogleIamCredentials) Reset()
func (*GoogleIamCredentials) String ¶
func (x *GoogleIamCredentials) String() string
func (*GoogleIamCredentials) Validate ¶
func (m *GoogleIamCredentials) Validate() error
Validate checks the field values on GoogleIamCredentials with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*GoogleIamCredentials) ValidateAll ¶
func (m *GoogleIamCredentials) ValidateAll() error
ValidateAll checks the field values on GoogleIamCredentials with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in GoogleIamCredentialsMultiError, or nil if none found.
type GoogleIamCredentialsMultiError ¶
type GoogleIamCredentialsMultiError []error
GoogleIamCredentialsMultiError is an error wrapping multiple validation errors returned by GoogleIamCredentials.ValidateAll() if the designated constraints aren't met.
func (GoogleIamCredentialsMultiError) AllErrors ¶
func (m GoogleIamCredentialsMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (GoogleIamCredentialsMultiError) Error ¶
func (m GoogleIamCredentialsMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type GoogleIamCredentialsValidationError ¶
type GoogleIamCredentialsValidationError struct {
// contains filtered or unexported fields
}
GoogleIamCredentialsValidationError is the validation error returned by GoogleIamCredentials.Validate if the designated constraints aren't met.
func (GoogleIamCredentialsValidationError) Cause ¶
func (e GoogleIamCredentialsValidationError) Cause() error
Cause function returns cause value.
func (GoogleIamCredentialsValidationError) Error ¶
func (e GoogleIamCredentialsValidationError) Error() string
Error satisfies the builtin error interface
func (GoogleIamCredentialsValidationError) ErrorName ¶
func (e GoogleIamCredentialsValidationError) ErrorName() string
ErrorName returns error name.
func (GoogleIamCredentialsValidationError) Field ¶
func (e GoogleIamCredentialsValidationError) Field() string
Field function returns field value.
func (GoogleIamCredentialsValidationError) Key ¶
func (e GoogleIamCredentialsValidationError) Key() bool
Key function returns key value.
func (GoogleIamCredentialsValidationError) Reason ¶
func (e GoogleIamCredentialsValidationError) Reason() string
Reason function returns reason value.
Source Files ¶
google_iam_credentials.pb.go google_iam_credentials.pb.validate.go
- Version
- v1.37.0 (latest)
- Published
- Jan 13, 2026
- Platform
- linux/amd64
- Imports
- 18 packages
- Last checked
- 2 hours ago –
Tools for package owners.