package client_writer_factoryv3
import "github.com/envoyproxy/go-control-plane/envoy/extensions/quic/client_writer_factory/v3"
Index ¶
- Variables
- type DefaultClientWriter
- func (*DefaultClientWriter) Descriptor() ([]byte, []int)
- func (*DefaultClientWriter) ProtoMessage()
- func (x *DefaultClientWriter) ProtoReflect() protoreflect.Message
- func (x *DefaultClientWriter) Reset()
- func (x *DefaultClientWriter) String() string
- func (m *DefaultClientWriter) Validate() error
- func (m *DefaultClientWriter) ValidateAll() error
- type DefaultClientWriterMultiError
- func (m DefaultClientWriterMultiError) AllErrors() []error
- func (m DefaultClientWriterMultiError) Error() string
- type DefaultClientWriterValidationError
- func (e DefaultClientWriterValidationError) Cause() error
- func (e DefaultClientWriterValidationError) Error() string
- func (e DefaultClientWriterValidationError) ErrorName() string
- func (e DefaultClientWriterValidationError) Field() string
- func (e DefaultClientWriterValidationError) Key() bool
- func (e DefaultClientWriterValidationError) Reason() string
Variables ¶
var File_envoy_extensions_quic_client_writer_factory_v3_default_client_writer_proto protoreflect.FileDescriptor
Types ¶
type DefaultClientWriter ¶
type DefaultClientWriter struct {
// contains filtered or unexported fields
}
The default QUIC packet writer used for QUIC upstream connections which is platform independent.
func (*DefaultClientWriter) Descriptor ¶
func (*DefaultClientWriter) Descriptor() ([]byte, []int)
Deprecated: Use DefaultClientWriter.ProtoReflect.Descriptor instead.
func (*DefaultClientWriter) ProtoMessage ¶
func (*DefaultClientWriter) ProtoMessage()
func (*DefaultClientWriter) ProtoReflect ¶
func (x *DefaultClientWriter) ProtoReflect() protoreflect.Message
func (*DefaultClientWriter) Reset ¶
func (x *DefaultClientWriter) Reset()
func (*DefaultClientWriter) String ¶
func (x *DefaultClientWriter) String() string
func (*DefaultClientWriter) Validate ¶
func (m *DefaultClientWriter) Validate() error
Validate checks the field values on DefaultClientWriter with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*DefaultClientWriter) ValidateAll ¶
func (m *DefaultClientWriter) ValidateAll() error
ValidateAll checks the field values on DefaultClientWriter with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in DefaultClientWriterMultiError, or nil if none found.
type DefaultClientWriterMultiError ¶
type DefaultClientWriterMultiError []error
DefaultClientWriterMultiError is an error wrapping multiple validation errors returned by DefaultClientWriter.ValidateAll() if the designated constraints aren't met.
func (DefaultClientWriterMultiError) AllErrors ¶
func (m DefaultClientWriterMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (DefaultClientWriterMultiError) Error ¶
func (m DefaultClientWriterMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type DefaultClientWriterValidationError ¶
type DefaultClientWriterValidationError struct {
// contains filtered or unexported fields
}
DefaultClientWriterValidationError is the validation error returned by DefaultClientWriter.Validate if the designated constraints aren't met.
func (DefaultClientWriterValidationError) Cause ¶
func (e DefaultClientWriterValidationError) Cause() error
Cause function returns cause value.
func (DefaultClientWriterValidationError) Error ¶
func (e DefaultClientWriterValidationError) Error() string
Error satisfies the builtin error interface
func (DefaultClientWriterValidationError) ErrorName ¶
func (e DefaultClientWriterValidationError) ErrorName() string
ErrorName returns error name.
func (DefaultClientWriterValidationError) Field ¶
func (e DefaultClientWriterValidationError) Field() string
Field function returns field value.
func (DefaultClientWriterValidationError) Key ¶
func (e DefaultClientWriterValidationError) Key() bool
Key function returns key value.
func (DefaultClientWriterValidationError) Reason ¶
func (e DefaultClientWriterValidationError) Reason() string
Reason function returns reason value.
Source Files ¶
default_client_writer.pb.go default_client_writer.pb.validate.go
- Version
- v1.37.0 (latest)
- Published
- Jan 13, 2026
- Platform
- linux/amd64
- Imports
- 18 packages
- Last checked
- 10 hours ago –
Tools for package owners.