package matcherv3
import "github.com/envoyproxy/go-control-plane/envoy/extensions/router/cluster_specifiers/matcher/v3"
Index ¶
- Variables
- type ClusterAction
- func (*ClusterAction) Descriptor() ([]byte, []int)
- func (x *ClusterAction) GetCluster() string
- func (*ClusterAction) ProtoMessage()
- func (x *ClusterAction) ProtoReflect() protoreflect.Message
- func (x *ClusterAction) Reset()
- func (x *ClusterAction) String() string
- func (m *ClusterAction) Validate() error
- func (m *ClusterAction) ValidateAll() error
- type ClusterActionMultiError
- func (m ClusterActionMultiError) AllErrors() []error
- func (m ClusterActionMultiError) Error() string
- type ClusterActionValidationError
- func (e ClusterActionValidationError) Cause() error
- func (e ClusterActionValidationError) Error() string
- func (e ClusterActionValidationError) ErrorName() string
- func (e ClusterActionValidationError) Field() string
- func (e ClusterActionValidationError) Key() bool
- func (e ClusterActionValidationError) Reason() string
- type MatcherClusterSpecifier
- func (*MatcherClusterSpecifier) Descriptor() ([]byte, []int)
- func (x *MatcherClusterSpecifier) GetClusterMatcher() *v3.Matcher
- func (*MatcherClusterSpecifier) ProtoMessage()
- func (x *MatcherClusterSpecifier) ProtoReflect() protoreflect.Message
- func (x *MatcherClusterSpecifier) Reset()
- func (x *MatcherClusterSpecifier) String() string
- func (m *MatcherClusterSpecifier) Validate() error
- func (m *MatcherClusterSpecifier) ValidateAll() error
- type MatcherClusterSpecifierMultiError
- func (m MatcherClusterSpecifierMultiError) AllErrors() []error
- func (m MatcherClusterSpecifierMultiError) Error() string
- type MatcherClusterSpecifierValidationError
- func (e MatcherClusterSpecifierValidationError) Cause() error
- func (e MatcherClusterSpecifierValidationError) Error() string
- func (e MatcherClusterSpecifierValidationError) ErrorName() string
- func (e MatcherClusterSpecifierValidationError) Field() string
- func (e MatcherClusterSpecifierValidationError) Key() bool
- func (e MatcherClusterSpecifierValidationError) Reason() string
Variables ¶
var File_envoy_extensions_router_cluster_specifiers_matcher_v3_matcher_proto protoreflect.FileDescriptor
Types ¶
type ClusterAction ¶
type ClusterAction struct {
// Indicates the upstream cluster to which the request should be routed
// to.
Cluster string `protobuf:"bytes,1,opt,name=cluster,proto3" json:"cluster,omitempty"`
// contains filtered or unexported fields
}
func (*ClusterAction) Descriptor ¶
func (*ClusterAction) Descriptor() ([]byte, []int)
Deprecated: Use ClusterAction.ProtoReflect.Descriptor instead.
func (*ClusterAction) GetCluster ¶
func (x *ClusterAction) GetCluster() string
func (*ClusterAction) ProtoMessage ¶
func (*ClusterAction) ProtoMessage()
func (*ClusterAction) ProtoReflect ¶
func (x *ClusterAction) ProtoReflect() protoreflect.Message
func (*ClusterAction) Reset ¶
func (x *ClusterAction) Reset()
func (*ClusterAction) String ¶
func (x *ClusterAction) String() string
func (*ClusterAction) Validate ¶
func (m *ClusterAction) Validate() error
Validate checks the field values on ClusterAction with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*ClusterAction) ValidateAll ¶
func (m *ClusterAction) ValidateAll() error
ValidateAll checks the field values on ClusterAction with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in ClusterActionMultiError, or nil if none found.
type ClusterActionMultiError ¶
type ClusterActionMultiError []error
ClusterActionMultiError is an error wrapping multiple validation errors returned by ClusterAction.ValidateAll() if the designated constraints aren't met.
func (ClusterActionMultiError) AllErrors ¶
func (m ClusterActionMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (ClusterActionMultiError) Error ¶
func (m ClusterActionMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type ClusterActionValidationError ¶
type ClusterActionValidationError struct {
// contains filtered or unexported fields
}
ClusterActionValidationError is the validation error returned by ClusterAction.Validate if the designated constraints aren't met.
func (ClusterActionValidationError) Cause ¶
func (e ClusterActionValidationError) Cause() error
Cause function returns cause value.
func (ClusterActionValidationError) Error ¶
func (e ClusterActionValidationError) Error() string
Error satisfies the builtin error interface
func (ClusterActionValidationError) ErrorName ¶
func (e ClusterActionValidationError) ErrorName() string
ErrorName returns error name.
func (ClusterActionValidationError) Field ¶
func (e ClusterActionValidationError) Field() string
Field function returns field value.
func (ClusterActionValidationError) Key ¶
func (e ClusterActionValidationError) Key() bool
Key function returns key value.
func (ClusterActionValidationError) Reason ¶
func (e ClusterActionValidationError) Reason() string
Reason function returns reason value.
type MatcherClusterSpecifier ¶
type MatcherClusterSpecifier struct {
// The matcher for cluster selection after the route has been selected. This is used when the
// route has multiple clusters (like multiple clusters for different users) and the matcher
// is used to select the cluster to use for the request.
//
// The match tree to use for grouping incoming requests into buckets.
//
// Example:
//
// .. validated-code-block:: yaml
//
// :type-name: xds.type.matcher.v3.Matcher
//
// matcher_list:
// matchers:
// - predicate:
// single_predicate:
// input:
// typed_config:
// '@type': type.googleapis.com/envoy.type.matcher.v3.HttpRequestHeaderMatchInput
// header_name: env
// value_match:
// exact: staging
// on_match:
// action:
// typed_config:
// '@type': type.googleapis.com/envoy.extensions.router.cluster_specifiers.matcher.v3.ClusterAction
// cluster: "staging-cluster"
//
// - predicate:
// single_predicate:
// input:
// typed_config:
// '@type': type.googleapis.com/envoy.type.matcher.v3.HttpRequestHeaderMatchInput
// header_name: env
// value_match:
// exact: prod
// on_match:
// action:
// typed_config:
// '@type': type.googleapis.com/envoy.extensions.router.cluster_specifiers.matcher.v3.ClusterAction
// cluster: "prod-cluster"
//
// # Catch-all with a default cluster.
// on_no_match:
// action:
// typed_config:
// '@type': type.googleapis.com/envoy.extensions.router.cluster_specifiers.matcher.v3.ClusterAction
// cluster: "default-cluster"
ClusterMatcher *v3.Matcher `protobuf:"bytes,1,opt,name=cluster_matcher,json=clusterMatcher,proto3" json:"cluster_matcher,omitempty"`
// contains filtered or unexported fields
}
func (*MatcherClusterSpecifier) Descriptor ¶
func (*MatcherClusterSpecifier) Descriptor() ([]byte, []int)
Deprecated: Use MatcherClusterSpecifier.ProtoReflect.Descriptor instead.
func (*MatcherClusterSpecifier) GetClusterMatcher ¶
func (x *MatcherClusterSpecifier) GetClusterMatcher() *v3.Matcher
func (*MatcherClusterSpecifier) ProtoMessage ¶
func (*MatcherClusterSpecifier) ProtoMessage()
func (*MatcherClusterSpecifier) ProtoReflect ¶
func (x *MatcherClusterSpecifier) ProtoReflect() protoreflect.Message
func (*MatcherClusterSpecifier) Reset ¶
func (x *MatcherClusterSpecifier) Reset()
func (*MatcherClusterSpecifier) String ¶
func (x *MatcherClusterSpecifier) String() string
func (*MatcherClusterSpecifier) Validate ¶
func (m *MatcherClusterSpecifier) Validate() error
Validate checks the field values on MatcherClusterSpecifier with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*MatcherClusterSpecifier) ValidateAll ¶
func (m *MatcherClusterSpecifier) ValidateAll() error
ValidateAll checks the field values on MatcherClusterSpecifier with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in MatcherClusterSpecifierMultiError, or nil if none found.
type MatcherClusterSpecifierMultiError ¶
type MatcherClusterSpecifierMultiError []error
MatcherClusterSpecifierMultiError is an error wrapping multiple validation errors returned by MatcherClusterSpecifier.ValidateAll() if the designated constraints aren't met.
func (MatcherClusterSpecifierMultiError) AllErrors ¶
func (m MatcherClusterSpecifierMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (MatcherClusterSpecifierMultiError) Error ¶
func (m MatcherClusterSpecifierMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type MatcherClusterSpecifierValidationError ¶
type MatcherClusterSpecifierValidationError struct {
// contains filtered or unexported fields
}
MatcherClusterSpecifierValidationError is the validation error returned by MatcherClusterSpecifier.Validate if the designated constraints aren't met.
func (MatcherClusterSpecifierValidationError) Cause ¶
func (e MatcherClusterSpecifierValidationError) Cause() error
Cause function returns cause value.
func (MatcherClusterSpecifierValidationError) Error ¶
func (e MatcherClusterSpecifierValidationError) Error() string
Error satisfies the builtin error interface
func (MatcherClusterSpecifierValidationError) ErrorName ¶
func (e MatcherClusterSpecifierValidationError) ErrorName() string
ErrorName returns error name.
func (MatcherClusterSpecifierValidationError) Field ¶
func (e MatcherClusterSpecifierValidationError) Field() string
Field function returns field value.
func (MatcherClusterSpecifierValidationError) Key ¶
func (e MatcherClusterSpecifierValidationError) Key() bool
Key function returns key value.
func (MatcherClusterSpecifierValidationError) Reason ¶
func (e MatcherClusterSpecifierValidationError) Reason() string
Reason function returns reason value.
Source Files ¶
matcher.pb.go matcher.pb.validate.go
- Version
- v1.37.0 (latest)
- Published
- Jan 13, 2026
- Platform
- linux/amd64
- Imports
- 20 packages
- Last checked
- 1 hour ago –
Tools for package owners.