package fluentdv3
import "github.com/envoyproxy/go-control-plane/envoy/extensions/tracers/fluentd/v3"
Index ¶
- Variables
- type FluentdConfig
- func (*FluentdConfig) Descriptor() ([]byte, []int)
- func (x *FluentdConfig) GetBufferFlushInterval() *durationpb.Duration
- func (x *FluentdConfig) GetBufferSizeBytes() *wrapperspb.UInt32Value
- func (x *FluentdConfig) GetCluster() string
- func (x *FluentdConfig) GetRetryPolicy() *v3.RetryPolicy
- func (x *FluentdConfig) GetStatPrefix() string
- func (x *FluentdConfig) GetTag() string
- func (*FluentdConfig) ProtoMessage()
- func (x *FluentdConfig) ProtoReflect() protoreflect.Message
- func (x *FluentdConfig) Reset()
- func (x *FluentdConfig) String() string
- func (m *FluentdConfig) Validate() error
- func (m *FluentdConfig) ValidateAll() error
- type FluentdConfigMultiError
- func (m FluentdConfigMultiError) AllErrors() []error
- func (m FluentdConfigMultiError) Error() string
- type FluentdConfigValidationError
- func (e FluentdConfigValidationError) Cause() error
- func (e FluentdConfigValidationError) Error() string
- func (e FluentdConfigValidationError) ErrorName() string
- func (e FluentdConfigValidationError) Field() string
- func (e FluentdConfigValidationError) Key() bool
- func (e FluentdConfigValidationError) Reason() string
Variables ¶
var File_envoy_extensions_tracers_fluentd_v3_fluentd_proto protoreflect.FileDescriptor
Types ¶
type FluentdConfig ¶
type FluentdConfig struct {
// The upstream cluster to connect to for streaming the Fluentd messages.
Cluster string `protobuf:"bytes,1,opt,name=cluster,proto3" json:"cluster,omitempty"`
// A tag is a string separated with “.“ (e.g. “log.type“) to categorize events.
// See: https://github.com/fluent/fluentd/wiki/Forward-Protocol-Specification-v1#message-modes
Tag string `protobuf:"bytes,2,opt,name=tag,proto3" json:"tag,omitempty"`
// The prefix to use when emitting tracer stats.
StatPrefix string `protobuf:"bytes,3,opt,name=stat_prefix,json=statPrefix,proto3" json:"stat_prefix,omitempty"`
// Interval for flushing traces to the TCP stream. Tracer will flush requests every time
// this interval is elapsed, or when batch size limit is hit, whichever comes first. Defaults to
// 1 second.
BufferFlushInterval *durationpb.Duration `protobuf:"bytes,4,opt,name=buffer_flush_interval,json=bufferFlushInterval,proto3" json:"buffer_flush_interval,omitempty"`
// Soft size limit in bytes for access log entries buffer. The logger will buffer requests until
// this limit it hit, or every time flush interval is elapsed, whichever comes first. When the buffer
// limit is hit, the logger will immediately flush the buffer contents. Setting it to zero effectively
// disables the batching. Defaults to 16384.
BufferSizeBytes *wrapperspb.UInt32Value `protobuf:"bytes,5,opt,name=buffer_size_bytes,json=bufferSizeBytes,proto3" json:"buffer_size_bytes,omitempty"`
// Optional retry, in case upstream connection has failed. If this field is not set, the default values will be applied.
RetryPolicy *v3.RetryPolicy `protobuf:"bytes,6,opt,name=retry_policy,json=retryPolicy,proto3" json:"retry_policy,omitempty"`
// contains filtered or unexported fields
}
Configuration for the Fluentd tracer. This tracer extension will send the emitted traces over a TCP connection to an upstream that is accepting the Fluentd Forward Protocol as described in: `Fluentd Forward Protocol Specification <https://github.com/fluent/fluentd/wiki/Forward-Protocol-Specification-v1>`_. [#extension: envoy.tracers.fluentd] [#next-free-field: 7]
func (*FluentdConfig) Descriptor ¶
func (*FluentdConfig) Descriptor() ([]byte, []int)
Deprecated: Use FluentdConfig.ProtoReflect.Descriptor instead.
func (*FluentdConfig) GetBufferFlushInterval ¶
func (x *FluentdConfig) GetBufferFlushInterval() *durationpb.Duration
func (*FluentdConfig) GetBufferSizeBytes ¶
func (x *FluentdConfig) GetBufferSizeBytes() *wrapperspb.UInt32Value
func (*FluentdConfig) GetCluster ¶
func (x *FluentdConfig) GetCluster() string
func (*FluentdConfig) GetRetryPolicy ¶
func (x *FluentdConfig) GetRetryPolicy() *v3.RetryPolicy
func (*FluentdConfig) GetStatPrefix ¶
func (x *FluentdConfig) GetStatPrefix() string
func (*FluentdConfig) GetTag ¶
func (x *FluentdConfig) GetTag() string
func (*FluentdConfig) ProtoMessage ¶
func (*FluentdConfig) ProtoMessage()
func (*FluentdConfig) ProtoReflect ¶
func (x *FluentdConfig) ProtoReflect() protoreflect.Message
func (*FluentdConfig) Reset ¶
func (x *FluentdConfig) Reset()
func (*FluentdConfig) String ¶
func (x *FluentdConfig) String() string
func (*FluentdConfig) Validate ¶
func (m *FluentdConfig) Validate() error
Validate checks the field values on FluentdConfig with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*FluentdConfig) ValidateAll ¶
func (m *FluentdConfig) ValidateAll() error
ValidateAll checks the field values on FluentdConfig with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in FluentdConfigMultiError, or nil if none found.
type FluentdConfigMultiError ¶
type FluentdConfigMultiError []error
FluentdConfigMultiError is an error wrapping multiple validation errors returned by FluentdConfig.ValidateAll() if the designated constraints aren't met.
func (FluentdConfigMultiError) AllErrors ¶
func (m FluentdConfigMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (FluentdConfigMultiError) Error ¶
func (m FluentdConfigMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type FluentdConfigValidationError ¶
type FluentdConfigValidationError struct {
// contains filtered or unexported fields
}
FluentdConfigValidationError is the validation error returned by FluentdConfig.Validate if the designated constraints aren't met.
func (FluentdConfigValidationError) Cause ¶
func (e FluentdConfigValidationError) Cause() error
Cause function returns cause value.
func (FluentdConfigValidationError) Error ¶
func (e FluentdConfigValidationError) Error() string
Error satisfies the builtin error interface
func (FluentdConfigValidationError) ErrorName ¶
func (e FluentdConfigValidationError) ErrorName() string
ErrorName returns error name.
func (FluentdConfigValidationError) Field ¶
func (e FluentdConfigValidationError) Field() string
Field function returns field value.
func (FluentdConfigValidationError) Key ¶
func (e FluentdConfigValidationError) Key() bool
Key function returns key value.
func (FluentdConfigValidationError) Reason ¶
func (e FluentdConfigValidationError) Reason() string
Reason function returns reason value.
Source Files ¶
fluentd.pb.go fluentd.pb.validate.go
- Version
- v1.37.0 (latest)
- Published
- Jan 13, 2026
- Platform
- linux/amd64
- Imports
- 22 packages
- Last checked
- 4 hours ago –
Tools for package owners.